Class: ESI::AssetsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby-esi/api/assets_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AssetsApi

Returns a new instance of AssetsApi.



19
20
21
# File 'lib/ruby-esi/api/assets_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ruby-esi/api/assets_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_characters_character_id_assets(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdAssetsGetInner>

Get character assets Return a list of the characters assets

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)
  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



33
34
35
36
# File 'lib/ruby-esi/api/assets_api.rb', line 33

def get_characters_character_id_assets(character_id, x_compatibility_date, opts = {})
  data, _status_code, _headers = get_characters_character_id_assets_with_http_info(character_id, x_compatibility_date, opts)
  data
end

#get_characters_character_id_assets_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdAssetsGetInner>, Integer, Hash)>

Get character assets Return a list of the characters assets

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)
  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/ruby-esi/api/assets_api.rb', line 49

def get_characters_character_id_assets_with_http_info(character_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.get_characters_character_id_assets ...'
  end
  # verify the required parameter 'character_id' is set
  if @api_client.config.client_side_validation && character_id.nil?
    fail ArgumentError, "Missing the required parameter 'character_id' when calling AssetsApi.get_characters_character_id_assets"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling AssetsApi.get_characters_character_id_assets"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AssetsApi.get_characters_character_id_assets, must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/characters/{character_id}/assets'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdAssetsGetInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"AssetsApi.get_characters_character_id_assets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#get_characters_character_id_assets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_corporations_corporation_id_assets(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdAssetsGetInner>

Get corporation assets Return a list of the corporation assets

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)
  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



131
132
133
134
# File 'lib/ruby-esi/api/assets_api.rb', line 131

def get_corporations_corporation_id_assets(corporation_id, x_compatibility_date, opts = {})
  data, _status_code, _headers = get_corporations_corporation_id_assets_with_http_info(corporation_id, x_compatibility_date, opts)
  data
end

#get_corporations_corporation_id_assets_with_http_info(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdAssetsGetInner>, Integer, Hash)>

Get corporation assets Return a list of the corporation assets

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)
  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/ruby-esi/api/assets_api.rb', line 147

def get_corporations_corporation_id_assets_with_http_info(corporation_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.get_corporations_corporation_id_assets ...'
  end
  # verify the required parameter 'corporation_id' is set
  if @api_client.config.client_side_validation && corporation_id.nil?
    fail ArgumentError, "Missing the required parameter 'corporation_id' when calling AssetsApi.get_corporations_corporation_id_assets"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling AssetsApi.get_corporations_corporation_id_assets"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling AssetsApi.get_corporations_corporation_id_assets, must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/corporations/{corporation_id}/assets'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CorporationsCorporationIdAssetsGetInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"AssetsApi.get_corporations_corporation_id_assets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#get_corporations_corporation_id_assets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_characters_character_id_assets_locations(character_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<CharactersCharacterIdAssetsLocationsPostInner>

Get character asset locations Return locations for a set of item ids, which you can get from character assets endpoint. Coordinates for items in hangars or stations are set to (0,0,0)

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



229
230
231
232
# File 'lib/ruby-esi/api/assets_api.rb', line 229

def post_characters_character_id_assets_locations(character_id, x_compatibility_date, request_body, opts = {})
  data, _status_code, _headers = post_characters_character_id_assets_locations_with_http_info(character_id, x_compatibility_date, request_body, opts)
  data
end

#post_characters_character_id_assets_locations_with_http_info(character_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<(Array<CharactersCharacterIdAssetsLocationsPostInner>, Integer, Hash)>

Get character asset locations Return locations for a set of item ids, which you can get from character assets endpoint. Coordinates for items in hangars or stations are set to (0,0,0)

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/ruby-esi/api/assets_api.rb', line 245

def post_characters_character_id_assets_locations_with_http_info(character_id, x_compatibility_date, request_body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.post_characters_character_id_assets_locations ...'
  end
  # verify the required parameter 'character_id' is set
  if @api_client.config.client_side_validation && character_id.nil?
    fail ArgumentError, "Missing the required parameter 'character_id' when calling AssetsApi.post_characters_character_id_assets_locations"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling AssetsApi.post_characters_character_id_assets_locations"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'request_body' is set
  if @api_client.config.client_side_validation && request_body.nil?
    fail ArgumentError, "Missing the required parameter 'request_body' when calling AssetsApi.post_characters_character_id_assets_locations"
  end
  if @api_client.config.client_side_validation && request_body.length > 1000
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_characters_character_id_assets_locations, number of items must be less than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && request_body.length < 1
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_characters_character_id_assets_locations, number of items must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/characters/{character_id}/assets/locations'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body)

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdAssetsLocationsPostInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"AssetsApi.post_characters_character_id_assets_locations",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#post_characters_character_id_assets_locations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_characters_character_id_assets_names(character_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<CharactersCharacterIdAssetsNamesPostInner>

Get character asset names Return names for a set of item ids, which you can get from character assets endpoint. Typically used for items that can customize names, like containers or ships.

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



339
340
341
342
# File 'lib/ruby-esi/api/assets_api.rb', line 339

def post_characters_character_id_assets_names(character_id, x_compatibility_date, request_body, opts = {})
  data, _status_code, _headers = post_characters_character_id_assets_names_with_http_info(character_id, x_compatibility_date, request_body, opts)
  data
end

#post_characters_character_id_assets_names_with_http_info(character_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<(Array<CharactersCharacterIdAssetsNamesPostInner>, Integer, Hash)>

Get character asset names Return names for a set of item ids, which you can get from character assets endpoint. Typically used for items that can customize names, like containers or ships.

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/ruby-esi/api/assets_api.rb', line 355

def post_characters_character_id_assets_names_with_http_info(character_id, x_compatibility_date, request_body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.post_characters_character_id_assets_names ...'
  end
  # verify the required parameter 'character_id' is set
  if @api_client.config.client_side_validation && character_id.nil?
    fail ArgumentError, "Missing the required parameter 'character_id' when calling AssetsApi.post_characters_character_id_assets_names"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling AssetsApi.post_characters_character_id_assets_names"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'request_body' is set
  if @api_client.config.client_side_validation && request_body.nil?
    fail ArgumentError, "Missing the required parameter 'request_body' when calling AssetsApi.post_characters_character_id_assets_names"
  end
  if @api_client.config.client_side_validation && request_body.length > 1000
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_characters_character_id_assets_names, number of items must be less than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && request_body.length < 1
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_characters_character_id_assets_names, number of items must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/characters/{character_id}/assets/names'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body)

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdAssetsNamesPostInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"AssetsApi.post_characters_character_id_assets_names",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#post_characters_character_id_assets_names\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_corporations_corporation_id_assets_locations(corporation_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<CharactersCharacterIdAssetsLocationsPostInner>

Get corporation asset locations Return locations for a set of item ids, which you can get from corporation assets endpoint. Coordinates for items in hangars or stations are set to (0,0,0)

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



449
450
451
452
# File 'lib/ruby-esi/api/assets_api.rb', line 449

def post_corporations_corporation_id_assets_locations(corporation_id, x_compatibility_date, request_body, opts = {})
  data, _status_code, _headers = post_corporations_corporation_id_assets_locations_with_http_info(corporation_id, x_compatibility_date, request_body, opts)
  data
end

#post_corporations_corporation_id_assets_locations_with_http_info(corporation_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<(Array<CharactersCharacterIdAssetsLocationsPostInner>, Integer, Hash)>

Get corporation asset locations Return locations for a set of item ids, which you can get from corporation assets endpoint. Coordinates for items in hangars or stations are set to (0,0,0)

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/ruby-esi/api/assets_api.rb', line 465

def post_corporations_corporation_id_assets_locations_with_http_info(corporation_id, x_compatibility_date, request_body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.post_corporations_corporation_id_assets_locations ...'
  end
  # verify the required parameter 'corporation_id' is set
  if @api_client.config.client_side_validation && corporation_id.nil?
    fail ArgumentError, "Missing the required parameter 'corporation_id' when calling AssetsApi.post_corporations_corporation_id_assets_locations"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling AssetsApi.post_corporations_corporation_id_assets_locations"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'request_body' is set
  if @api_client.config.client_side_validation && request_body.nil?
    fail ArgumentError, "Missing the required parameter 'request_body' when calling AssetsApi.post_corporations_corporation_id_assets_locations"
  end
  if @api_client.config.client_side_validation && request_body.length > 1000
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_corporations_corporation_id_assets_locations, number of items must be less than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && request_body.length < 1
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_corporations_corporation_id_assets_locations, number of items must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/corporations/{corporation_id}/assets/locations'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body)

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdAssetsLocationsPostInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"AssetsApi.post_corporations_corporation_id_assets_locations",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#post_corporations_corporation_id_assets_locations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_corporations_corporation_id_assets_names(corporation_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<CharactersCharacterIdAssetsNamesPostInner>

Get corporation asset names Return names for a set of item ids, which you can get from corporation assets endpoint. Only valid for items that can customize names, like containers or ships

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



559
560
561
562
# File 'lib/ruby-esi/api/assets_api.rb', line 559

def post_corporations_corporation_id_assets_names(corporation_id, x_compatibility_date, request_body, opts = {})
  data, _status_code, _headers = post_corporations_corporation_id_assets_names_with_http_info(corporation_id, x_compatibility_date, request_body, opts)
  data
end

#post_corporations_corporation_id_assets_names_with_http_info(corporation_id, x_compatibility_date, request_body, opts = {}) ⇒ Array<(Array<CharactersCharacterIdAssetsNamesPostInner>, Integer, Hash)>

Get corporation asset names Return names for a set of item ids, which you can get from corporation assets endpoint. Only valid for items that can customize names, like containers or ships

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • request_body (Array<Integer>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/ruby-esi/api/assets_api.rb', line 575

def post_corporations_corporation_id_assets_names_with_http_info(corporation_id, x_compatibility_date, request_body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.post_corporations_corporation_id_assets_names ...'
  end
  # verify the required parameter 'corporation_id' is set
  if @api_client.config.client_side_validation && corporation_id.nil?
    fail ArgumentError, "Missing the required parameter 'corporation_id' when calling AssetsApi.post_corporations_corporation_id_assets_names"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling AssetsApi.post_corporations_corporation_id_assets_names"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'request_body' is set
  if @api_client.config.client_side_validation && request_body.nil?
    fail ArgumentError, "Missing the required parameter 'request_body' when calling AssetsApi.post_corporations_corporation_id_assets_names"
  end
  if @api_client.config.client_side_validation && request_body.length > 1000
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_corporations_corporation_id_assets_names, number of items must be less than or equal to 1000.'
  end

  if @api_client.config.client_side_validation && request_body.length < 1
    fail ArgumentError, 'invalid value for "request_body" when calling AssetsApi.post_corporations_corporation_id_assets_names, number of items must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/corporations/{corporation_id}/assets/names'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body)

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdAssetsNamesPostInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"AssetsApi.post_corporations_corporation_id_assets_names",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#post_corporations_corporation_id_assets_names\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end