Class: ESI::CharactersAffiliationPostInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersAffiliationPostInner
- Defined in:
- lib/ruby-esi/models/characters_affiliation_post_inner.rb
Instance Attribute Summary collapse
-
#alliance_id ⇒ Object
The character’s alliance ID, if their corporation is in an alliance.
-
#character_id ⇒ Object
The character’s ID.
-
#corporation_id ⇒ Object
The character’s corporation ID.
-
#faction_id ⇒ Object
The character’s faction ID, if their corporation is in a faction.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersAffiliationPostInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersAffiliationPostInner
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersAffiliationPostInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersAffiliationPostInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'alliance_id') self.alliance_id = attributes[:'alliance_id'] end if attributes.key?(:'character_id') self.character_id = attributes[:'character_id'] else self.character_id = nil end if attributes.key?(:'corporation_id') self.corporation_id = attributes[:'corporation_id'] else self.corporation_id = nil end if attributes.key?(:'faction_id') self.faction_id = attributes[:'faction_id'] end end |
Instance Attribute Details
#alliance_id ⇒ Object
The character’s alliance ID, if their corporation is in an alliance
19 20 21 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 19 def alliance_id @alliance_id end |
#character_id ⇒ Object
The character’s ID
22 23 24 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 22 def character_id @character_id end |
#corporation_id ⇒ Object
The character’s corporation ID
25 26 27 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 25 def corporation_id @corporation_id end |
#faction_id ⇒ Object
The character’s faction ID, if their corporation is in a faction
28 29 30 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 28 def faction_id @faction_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 31 def self.attribute_map { :'alliance_id' => :'alliance_id', :'character_id' => :'character_id', :'corporation_id' => :'corporation_id', :'faction_id' => :'faction_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 51 def self.openapi_types { :'alliance_id' => :'Integer', :'character_id' => :'Integer', :'corporation_id' => :'Integer', :'faction_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && alliance_id == o.alliance_id && character_id == o.character_id && corporation_id == o.corporation_id && faction_id == o.faction_id end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 167 def hash [alliance_id, character_id, corporation_id, faction_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @character_id.nil? invalid_properties.push('invalid value for "character_id", character_id cannot be nil.') end if @corporation_id.nil? invalid_properties.push('invalid value for "corporation_id", corporation_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 126 |
# File 'lib/ruby-esi/models/characters_affiliation_post_inner.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @character_id.nil? return false if @corporation_id.nil? true end |