Class: ESI::CharactersCharacterIdAssetsGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_assets_get_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdAssetsGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdAssetsGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdAssetsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_blueprint_copy')
    self.is_blueprint_copy = attributes[:'is_blueprint_copy']
  end

  if attributes.key?(:'is_singleton')
    self.is_singleton = attributes[:'is_singleton']
  else
    self.is_singleton = nil
  end

  if attributes.key?(:'item_id')
    self.item_id = attributes[:'item_id']
  else
    self.item_id = nil
  end

  if attributes.key?(:'location_flag')
    self.location_flag = attributes[:'location_flag']
  else
    self.location_flag = nil
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  else
    self.location_id = nil
  end

  if attributes.key?(:'location_type')
    self.location_type = attributes[:'location_type']
  else
    self.location_type = nil
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  else
    self.quantity = nil
  end

  if attributes.key?(:'type_id')
    self.type_id = attributes[:'type_id']
  else
    self.type_id = nil
  end
end

Instance Attribute Details

#is_blueprint_copyObject

Returns the value of attribute is_blueprint_copy.



18
19
20
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 18

def is_blueprint_copy
  @is_blueprint_copy
end

#is_singletonObject

Returns the value of attribute is_singleton.



20
21
22
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 20

def is_singleton
  @is_singleton
end

#item_idObject

Returns the value of attribute item_id.



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 22

def item_id
  @item_id
end

#location_flagObject

Returns the value of attribute location_flag.



24
25
26
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 24

def location_flag
  @location_flag
end

#location_idObject

Returns the value of attribute location_id.



26
27
28
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 26

def location_id
  @location_id
end

#location_typeObject

Returns the value of attribute location_type.



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 28

def location_type
  @location_type
end

#quantityObject

Returns the value of attribute quantity.



30
31
32
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 30

def quantity
  @quantity
end

#type_idObject

Returns the value of attribute type_id.



32
33
34
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 32

def type_id
  @type_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 57

def self.attribute_map
  {
    :'is_blueprint_copy' => :'is_blueprint_copy',
    :'is_singleton' => :'is_singleton',
    :'item_id' => :'item_id',
    :'location_flag' => :'location_flag',
    :'location_id' => :'location_id',
    :'location_type' => :'location_type',
    :'quantity' => :'quantity',
    :'type_id' => :'type_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 81

def self.openapi_types
  {
    :'is_blueprint_copy' => :'Boolean',
    :'is_singleton' => :'Boolean',
    :'item_id' => :'Integer',
    :'location_flag' => :'String',
    :'location_id' => :'Integer',
    :'location_type' => :'String',
    :'quantity' => :'Integer',
    :'type_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_blueprint_copy == o.is_blueprint_copy &&
      is_singleton == o.is_singleton &&
      item_id == o.item_id &&
      location_flag == o.location_flag &&
      location_id == o.location_id &&
      location_type == o.location_type &&
      quantity == o.quantity &&
      type_id == o.type_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 310

def hash
  [is_blueprint_copy, is_singleton, item_id, location_flag, location_id, location_type, quantity, type_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @is_singleton.nil?
    invalid_properties.push('invalid value for "is_singleton", is_singleton cannot be nil.')
  end

  if @item_id.nil?
    invalid_properties.push('invalid value for "item_id", item_id cannot be nil.')
  end

  if @location_flag.nil?
    invalid_properties.push('invalid value for "location_flag", location_flag cannot be nil.')
  end

  if @location_id.nil?
    invalid_properties.push('invalid value for "location_id", location_id cannot be nil.')
  end

  if @location_type.nil?
    invalid_properties.push('invalid value for "location_type", location_type cannot be nil.')
  end

  if @quantity.nil?
    invalid_properties.push('invalid value for "quantity", quantity cannot be nil.')
  end

  if @type_id.nil?
    invalid_properties.push('invalid value for "type_id", type_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/ruby-esi/models/characters_character_id_assets_get_inner.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @is_singleton.nil?
  return false if @item_id.nil?
  return false if @location_flag.nil?
  location_flag_validator = EnumAttributeValidator.new('String', ["AssetSafety", "AutoFit", "BoosterBay", "CapsuleerDeliveries", "Cargo", "CorporationGoalDeliveries", "CorpseBay", "Deliveries", "DroneBay", "ExpeditionHold", "FighterBay", "FighterTube0", "FighterTube1", "FighterTube2", "FighterTube3", "FighterTube4", "FleetHangar", "FrigateEscapeBay", "Hangar", "HangarAll", "HiSlot0", "HiSlot1", "HiSlot2", "HiSlot3", "HiSlot4", "HiSlot5", "HiSlot6", "HiSlot7", "HiddenModifiers", "Implant", "InfrastructureHangar", "LoSlot0", "LoSlot1", "LoSlot2", "LoSlot3", "LoSlot4", "LoSlot5", "LoSlot6", "LoSlot7", "Locked", "MedSlot0", "MedSlot1", "MedSlot2", "MedSlot3", "MedSlot4", "MedSlot5", "MedSlot6", "MedSlot7", "MobileDepotHold", "MoonMaterialBay", "QuafeBay", "RigSlot0", "RigSlot1", "RigSlot2", "RigSlot3", "RigSlot4", "RigSlot5", "RigSlot6", "RigSlot7", "ShipHangar", "Skill", "SpecializedAmmoHold", "SpecializedAsteroidHold", "SpecializedCommandCenterHold", "SpecializedFuelBay", "SpecializedGasHold", "SpecializedIceHold", "SpecializedIndustrialShipHold", "SpecializedLargeShipHold", "SpecializedMaterialBay", "SpecializedMediumShipHold", "SpecializedMineralHold", "SpecializedOreHold", "SpecializedPlanetaryCommoditiesHold", "SpecializedSalvageHold", "SpecializedShipHold", "SpecializedSmallShipHold", "StructureDeedBay", "SubSystemBay", "SubSystemSlot0", "SubSystemSlot1", "SubSystemSlot2", "SubSystemSlot3", "SubSystemSlot4", "SubSystemSlot5", "SubSystemSlot6", "SubSystemSlot7", "Unlocked", "Wardrobe"])
  return false unless location_flag_validator.valid?(@location_flag)
  return false if @location_id.nil?
  return false if @location_type.nil?
  location_type_validator = EnumAttributeValidator.new('String', ["station", "solar_system", "item", "other"])
  return false unless location_type_validator.valid?(@location_type)
  return false if @quantity.nil?
  return false if @type_id.nil?
  true
end