Class: ESI::CharactersCharacterIdAttributesGet

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_attributes_get.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdAttributesGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdAttributesGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdAttributesGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'accrued_remap_cooldown_date')
    self.accrued_remap_cooldown_date = attributes[:'accrued_remap_cooldown_date']
  end

  if attributes.key?(:'bonus_remaps')
    self.bonus_remaps = attributes[:'bonus_remaps']
  end

  if attributes.key?(:'charisma')
    self.charisma = attributes[:'charisma']
  else
    self.charisma = nil
  end

  if attributes.key?(:'intelligence')
    self.intelligence = attributes[:'intelligence']
  else
    self.intelligence = nil
  end

  if attributes.key?(:'last_remap_date')
    self.last_remap_date = attributes[:'last_remap_date']
  end

  if attributes.key?(:'memory')
    self.memory = attributes[:'memory']
  else
    self.memory = nil
  end

  if attributes.key?(:'perception')
    self.perception = attributes[:'perception']
  else
    self.perception = nil
  end

  if attributes.key?(:'willpower')
    self.willpower = attributes[:'willpower']
  else
    self.willpower = nil
  end
end

Instance Attribute Details

#accrued_remap_cooldown_dateObject

Neural remapping cooldown after a character uses remap accrued over time



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 19

def accrued_remap_cooldown_date
  @accrued_remap_cooldown_date
end

#bonus_remapsObject

Number of available bonus character neural remaps



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 22

def bonus_remaps
  @bonus_remaps
end

#charismaObject

Returns the value of attribute charisma.



24
25
26
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 24

def charisma
  @charisma
end

#intelligenceObject

Returns the value of attribute intelligence.



26
27
28
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 26

def intelligence
  @intelligence
end

#last_remap_dateObject

Datetime of last neural remap, including usage of bonus remaps



29
30
31
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 29

def last_remap_date
  @last_remap_date
end

#memoryObject

Returns the value of attribute memory.



31
32
33
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 31

def memory
  @memory
end

#perceptionObject

Returns the value of attribute perception.



33
34
35
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 33

def perception
  @perception
end

#willpowerObject

Returns the value of attribute willpower.



35
36
37
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 35

def willpower
  @willpower
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 38

def self.attribute_map
  {
    :'accrued_remap_cooldown_date' => :'accrued_remap_cooldown_date',
    :'bonus_remaps' => :'bonus_remaps',
    :'charisma' => :'charisma',
    :'intelligence' => :'intelligence',
    :'last_remap_date' => :'last_remap_date',
    :'memory' => :'memory',
    :'perception' => :'perception',
    :'willpower' => :'willpower'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 62

def self.openapi_types
  {
    :'accrued_remap_cooldown_date' => :'Time',
    :'bonus_remaps' => :'Integer',
    :'charisma' => :'Integer',
    :'intelligence' => :'Integer',
    :'last_remap_date' => :'Time',
    :'memory' => :'Integer',
    :'perception' => :'Integer',
    :'willpower' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      accrued_remap_cooldown_date == o.accrued_remap_cooldown_date &&
      bonus_remaps == o.bonus_remaps &&
      charisma == o.charisma &&
      intelligence == o.intelligence &&
      last_remap_date == o.last_remap_date &&
      memory == o.memory &&
      perception == o.perception &&
      willpower == o.willpower
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 253

def hash
  [accrued_remap_cooldown_date, bonus_remaps, charisma, intelligence, last_remap_date, memory, perception, willpower].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @charisma.nil?
    invalid_properties.push('invalid value for "charisma", charisma cannot be nil.')
  end

  if @intelligence.nil?
    invalid_properties.push('invalid value for "intelligence", intelligence cannot be nil.')
  end

  if @memory.nil?
    invalid_properties.push('invalid value for "memory", memory cannot be nil.')
  end

  if @perception.nil?
    invalid_properties.push('invalid value for "perception", perception cannot be nil.')
  end

  if @willpower.nil?
    invalid_properties.push('invalid value for "willpower", willpower cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 282

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
# File 'lib/ruby-esi/models/characters_character_id_attributes_get.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @charisma.nil?
  return false if @intelligence.nil?
  return false if @memory.nil?
  return false if @perception.nil?
  return false if @willpower.nil?
  true
end