Class: ESI::CharactersCharacterIdClonesGet
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdClonesGet
- Defined in:
- lib/ruby-esi/models/characters_character_id_clones_get.rb
Instance Attribute Summary collapse
-
#home_location ⇒ Object
Returns the value of attribute home_location.
-
#jump_clones ⇒ Object
Returns the value of attribute jump_clones.
-
#last_clone_jump_date ⇒ Object
Returns the value of attribute last_clone_jump_date.
-
#last_station_change_date ⇒ Object
Returns the value of attribute last_station_change_date.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdClonesGet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdClonesGet
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdClonesGet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdClonesGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'home_location') self.home_location = attributes[:'home_location'] end if attributes.key?(:'jump_clones') if (value = attributes[:'jump_clones']).is_a?(Array) self.jump_clones = value end else self.jump_clones = nil end if attributes.key?(:'last_clone_jump_date') self.last_clone_jump_date = attributes[:'last_clone_jump_date'] end if attributes.key?(:'last_station_change_date') self.last_station_change_date = attributes[:'last_station_change_date'] end end |
Instance Attribute Details
#home_location ⇒ Object
Returns the value of attribute home_location.
18 19 20 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 18 def home_location @home_location end |
#jump_clones ⇒ Object
Returns the value of attribute jump_clones.
20 21 22 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 20 def jump_clones @jump_clones end |
#last_clone_jump_date ⇒ Object
Returns the value of attribute last_clone_jump_date.
22 23 24 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 22 def last_clone_jump_date @last_clone_jump_date end |
#last_station_change_date ⇒ Object
Returns the value of attribute last_station_change_date.
24 25 26 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 24 def last_station_change_date @last_station_change_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 27 def self.attribute_map { :'home_location' => :'home_location', :'jump_clones' => :'jump_clones', :'last_clone_jump_date' => :'last_clone_jump_date', :'last_station_change_date' => :'last_station_change_date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 155 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 47 def self.openapi_types { :'home_location' => :'CharactersCharacterIdClonesGetHomeLocation', :'jump_clones' => :'Array<CharactersCharacterIdClonesGetJumpClonesInner>', :'last_clone_jump_date' => :'Time', :'last_station_change_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && home_location == o.home_location && jump_clones == o.jump_clones && last_clone_jump_date == o.last_clone_jump_date && last_station_change_date == o.last_station_change_date end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 148 def hash [home_location, jump_clones, last_clone_jump_date, last_station_change_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
101 102 103 104 105 106 107 108 109 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 101 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @jump_clones.nil? invalid_properties.push('invalid value for "jump_clones", jump_clones cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 117 |
# File 'lib/ruby-esi/models/characters_character_id_clones_get.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @jump_clones.nil? true end |