Class: ESI::CharactersCharacterIdFwStatsGet

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/characters_character_id_fw_stats_get.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdFwStatsGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdFwStatsGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdFwStatsGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'current_rank')
    self.current_rank = attributes[:'current_rank']
  end

  if attributes.key?(:'enlisted_on')
    self.enlisted_on = attributes[:'enlisted_on']
  end

  if attributes.key?(:'faction_id')
    self.faction_id = attributes[:'faction_id']
  end

  if attributes.key?(:'highest_rank')
    self.highest_rank = attributes[:'highest_rank']
  end

  if attributes.key?(:'kills')
    self.kills = attributes[:'kills']
  else
    self.kills = nil
  end

  if attributes.key?(:'victory_points')
    self.victory_points = attributes[:'victory_points']
  else
    self.victory_points = nil
  end
end

Instance Attribute Details

#current_rankObject

The given character’s current faction rank



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 19

def current_rank
  @current_rank
end

#enlisted_onObject

The enlistment date of the given character into faction warfare. Will not be included if character is not enlisted in faction warfare



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 22

def enlisted_on
  @enlisted_on
end

#faction_idObject

The faction the given character is enlisted to fight for. Will not be included if character is not enlisted in faction warfare



25
26
27
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 25

def faction_id
  @faction_id
end

#highest_rankObject

The given character’s highest faction rank achieved



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 28

def highest_rank
  @highest_rank
end

#killsObject

Returns the value of attribute kills.



30
31
32
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 30

def kills
  @kills
end

#victory_pointsObject

Returns the value of attribute victory_points.



32
33
34
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 32

def victory_points
  @victory_points
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 35

def self.attribute_map
  {
    :'current_rank' => :'current_rank',
    :'enlisted_on' => :'enlisted_on',
    :'faction_id' => :'faction_id',
    :'highest_rank' => :'highest_rank',
    :'kills' => :'kills',
    :'victory_points' => :'victory_points'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 57

def self.openapi_types
  {
    :'current_rank' => :'Integer',
    :'enlisted_on' => :'Time',
    :'faction_id' => :'Integer',
    :'highest_rank' => :'Integer',
    :'kills' => :'CharactersCharacterIdFwStatsGetKills',
    :'victory_points' => :'CharactersCharacterIdFwStatsGetVictoryPoints'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      current_rank == o.current_rank &&
      enlisted_on == o.enlisted_on &&
      faction_id == o.faction_id &&
      highest_rank == o.highest_rank &&
      kills == o.kills &&
      victory_points == o.victory_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 185

def hash
  [current_rank, enlisted_on, faction_id, highest_rank, kills, victory_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @kills.nil?
    invalid_properties.push('invalid value for "kills", kills cannot be nil.')
  end

  if @victory_points.nil?
    invalid_properties.push('invalid value for "victory_points", victory_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
# File 'lib/ruby-esi/models/characters_character_id_fw_stats_get.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @kills.nil?
  return false if @victory_points.nil?
  true
end