Class: ESI::CharactersCharacterIdGet

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/characters_character_id_get.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alliance_id')
    self.alliance_id = attributes[:'alliance_id']
  end

  if attributes.key?(:'birthday')
    self.birthday = attributes[:'birthday']
  else
    self.birthday = nil
  end

  if attributes.key?(:'bloodline_id')
    self.bloodline_id = attributes[:'bloodline_id']
  else
    self.bloodline_id = nil
  end

  if attributes.key?(:'corporation_id')
    self.corporation_id = attributes[:'corporation_id']
  else
    self.corporation_id = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'faction_id')
    self.faction_id = attributes[:'faction_id']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  else
    self.gender = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'race_id')
    self.race_id = attributes[:'race_id']
  else
    self.race_id = nil
  end

  if attributes.key?(:'security_status')
    self.security_status = attributes[:'security_status']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end
end

Instance Attribute Details

#alliance_idObject

The character’s alliance ID



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 19

def alliance_id
  @alliance_id
end

#birthdayObject

Creation date of the character



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 22

def birthday
  @birthday
end

#bloodline_idObject

Returns the value of attribute bloodline_id.



24
25
26
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 24

def bloodline_id
  @bloodline_id
end

#corporation_idObject

The character’s corporation ID



27
28
29
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 27

def corporation_id
  @corporation_id
end

#descriptionObject

Returns the value of attribute description.



29
30
31
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 29

def description
  @description
end

#faction_idObject

ID of the faction the character is fighting for, if the character is enlisted in Factional Warfare



32
33
34
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 32

def faction_id
  @faction_id
end

#genderObject

Returns the value of attribute gender.



34
35
36
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 34

def gender
  @gender
end

#nameObject

Returns the value of attribute name.



36
37
38
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 36

def name
  @name
end

#race_idObject

Returns the value of attribute race_id.



38
39
40
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 38

def race_id
  @race_id
end

#security_statusObject

Returns the value of attribute security_status.



40
41
42
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 40

def security_status
  @security_status
end

#titleObject

The individual title of the character



43
44
45
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 43

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 68

def self.attribute_map
  {
    :'alliance_id' => :'alliance_id',
    :'birthday' => :'birthday',
    :'bloodline_id' => :'bloodline_id',
    :'corporation_id' => :'corporation_id',
    :'description' => :'description',
    :'faction_id' => :'faction_id',
    :'gender' => :'gender',
    :'name' => :'name',
    :'race_id' => :'race_id',
    :'security_status' => :'security_status',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 95

def self.openapi_types
  {
    :'alliance_id' => :'Integer',
    :'birthday' => :'Time',
    :'bloodline_id' => :'Integer',
    :'corporation_id' => :'Integer',
    :'description' => :'String',
    :'faction_id' => :'Integer',
    :'gender' => :'String',
    :'name' => :'String',
    :'race_id' => :'Integer',
    :'security_status' => :'Float',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 299

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alliance_id == o.alliance_id &&
      birthday == o.birthday &&
      bloodline_id == o.bloodline_id &&
      corporation_id == o.corporation_id &&
      description == o.description &&
      faction_id == o.faction_id &&
      gender == o.gender &&
      name == o.name &&
      race_id == o.race_id &&
      security_status == o.security_status &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 317

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



323
324
325
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 323

def hash
  [alliance_id, birthday, bloodline_id, corporation_id, description, faction_id, gender, name, race_id, security_status, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @birthday.nil?
    invalid_properties.push('invalid value for "birthday", birthday cannot be nil.')
  end

  if @bloodline_id.nil?
    invalid_properties.push('invalid value for "bloodline_id", bloodline_id cannot be nil.')
  end

  if @corporation_id.nil?
    invalid_properties.push('invalid value for "corporation_id", corporation_id cannot be nil.')
  end

  if @gender.nil?
    invalid_properties.push('invalid value for "gender", gender cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @race_id.nil?
    invalid_properties.push('invalid value for "race_id", race_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/ruby-esi/models/characters_character_id_get.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @birthday.nil?
  return false if @bloodline_id.nil?
  return false if @corporation_id.nil?
  return false if @gender.nil?
  gender_validator = EnumAttributeValidator.new('String', ["female", "male"])
  return false unless gender_validator.valid?(@gender)
  return false if @name.nil?
  return false if @race_id.nil?
  true
end