Class: ESI::CharactersCharacterIdMailGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_mail_get_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdMailGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdMailGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdMailGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'is_read')
    self.is_read = attributes[:'is_read']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'mail_id')
    self.mail_id = attributes[:'mail_id']
  end

  if attributes.key?(:'recipients')
    if (value = attributes[:'recipients']).is_a?(Array)
      self.recipients = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end
end

Instance Attribute Details

#fromObject

From whom the mail was sent



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 19

def from
  @from
end

#is_readObject

Returns the value of attribute is_read.



21
22
23
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 21

def is_read
  @is_read
end

#labelsObject

Returns the value of attribute labels.



23
24
25
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 23

def labels
  @labels
end

#mail_idObject

Returns the value of attribute mail_id.



25
26
27
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 25

def mail_id
  @mail_id
end

#recipientsObject

Recipients of the mail



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 28

def recipients
  @recipients
end

#subjectObject

Mail subject



31
32
33
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 31

def subject
  @subject
end

#timestampObject

When the mail was sent



34
35
36
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 34

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 37

def self.attribute_map
  {
    :'from' => :'from',
    :'is_read' => :'is_read',
    :'labels' => :'labels',
    :'mail_id' => :'mail_id',
    :'recipients' => :'recipients',
    :'subject' => :'subject',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 60

def self.openapi_types
  {
    :'from' => :'Integer',
    :'is_read' => :'Boolean',
    :'labels' => :'Array<Integer>',
    :'mail_id' => :'Integer',
    :'recipients' => :'Array<PostCharactersCharacterIdMailRequestRecipientsInner>',
    :'subject' => :'String',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
171
172
173
174
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      is_read == o.is_read &&
      labels == o.labels &&
      mail_id == o.mail_id &&
      recipients == o.recipients &&
      subject == o.subject &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 184

def hash
  [from, is_read, labels, mail_id, recipients, subject, timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
# File 'lib/ruby-esi/models/characters_character_id_mail_get_inner.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end