Class: ESI::CharactersCharacterIdMailLabelsGetLabelsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdMailLabelsGetLabelsInner
- Defined in:
- lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb
Overview
label object
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#color ⇒ Object
Returns the value of attribute color.
-
#label_id ⇒ Object
Returns the value of attribute label_id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#unread_count ⇒ Object
Returns the value of attribute unread_count.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdMailLabelsGetLabelsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdMailLabelsGetLabelsInner
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdMailLabelsGetLabelsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdMailLabelsGetLabelsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'color') self.color = attributes[:'color'] else self.color = '#ffffff' end if attributes.key?(:'label_id') self.label_id = attributes[:'label_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'unread_count') self.unread_count = attributes[:'unread_count'] end end |
Instance Attribute Details
#color ⇒ Object
Returns the value of attribute color.
19 20 21 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 19 def color @color end |
#label_id ⇒ Object
Returns the value of attribute label_id.
21 22 23 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 21 def label_id @label_id end |
#name ⇒ Object
Returns the value of attribute name.
23 24 25 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 23 def name @name end |
#unread_count ⇒ Object
Returns the value of attribute unread_count.
25 26 27 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 25 def unread_count @unread_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 50 def self.attribute_map { :'color' => :'color', :'label_id' => :'label_id', :'name' => :'name', :'unread_count' => :'unread_count' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 70 def self.openapi_types { :'color' => :'String', :'label_id' => :'Integer', :'name' => :'String', :'unread_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && color == o.color && label_id == o.label_id && name == o.name && unread_count == o.unread_count end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 166 def hash [color, label_id, name, unread_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 122 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 135 |
# File 'lib/ruby-esi/models/characters_character_id_mail_labels_get_labels_inner.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' color_validator = EnumAttributeValidator.new('String', ["#0000fe", "#006634", "#0099ff", "#00ff33", "#01ffff", "#349800", "#660066", "#666666", "#999999", "#99ffff", "#9a0000", "#ccff9a", "#e6e6e6", "#fe0000", "#ff6600", "#ffff01", "#ffffcd", "#ffffff"]) return false unless color_validator.valid?(@color) true end |