Class: ESI::CharactersCharacterIdMedalsGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_medals_get_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdMedalsGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdMedalsGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdMedalsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'corporation_id')
    self.corporation_id = attributes[:'corporation_id']
  else
    self.corporation_id = nil
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'graphics')
    if (value = attributes[:'graphics']).is_a?(Array)
      self.graphics = value
    end
  else
    self.graphics = nil
  end

  if attributes.key?(:'issuer_id')
    self.issuer_id = attributes[:'issuer_id']
  else
    self.issuer_id = nil
  end

  if attributes.key?(:'medal_id')
    self.medal_id = attributes[:'medal_id']
  else
    self.medal_id = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end
end

Instance Attribute Details

#corporation_idObject

Returns the value of attribute corporation_id.



18
19
20
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 18

def corporation_id
  @corporation_id
end

#dateObject

Returns the value of attribute date.



20
21
22
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 20

def date
  @date
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 22

def description
  @description
end

#graphicsObject

Returns the value of attribute graphics.



24
25
26
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 24

def graphics
  @graphics
end

#issuer_idObject

Returns the value of attribute issuer_id.



26
27
28
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 26

def issuer_id
  @issuer_id
end

#medal_idObject

Returns the value of attribute medal_id.



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 28

def medal_id
  @medal_id
end

#reasonObject

Returns the value of attribute reason.



30
31
32
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 30

def reason
  @reason
end

#statusObject

Returns the value of attribute status.



32
33
34
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 32

def status
  @status
end

#titleObject

Returns the value of attribute title.



34
35
36
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 34

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 59

def self.attribute_map
  {
    :'corporation_id' => :'corporation_id',
    :'date' => :'date',
    :'description' => :'description',
    :'graphics' => :'graphics',
    :'issuer_id' => :'issuer_id',
    :'medal_id' => :'medal_id',
    :'reason' => :'reason',
    :'status' => :'status',
    :'title' => :'title'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 360

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 84

def self.openapi_types
  {
    :'corporation_id' => :'Integer',
    :'date' => :'Time',
    :'description' => :'String',
    :'graphics' => :'Array<CharactersCharacterIdMedalsGetInnerGraphicsInner>',
    :'issuer_id' => :'Integer',
    :'medal_id' => :'Integer',
    :'reason' => :'String',
    :'status' => :'String',
    :'title' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 331

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      corporation_id == o.corporation_id &&
      date == o.date &&
      description == o.description &&
      graphics == o.graphics &&
      issuer_id == o.issuer_id &&
      medal_id == o.medal_id &&
      reason == o.reason &&
      status == o.status &&
      title == o.title
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


347
348
349
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 347

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



353
354
355
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 353

def hash
  [corporation_id, date, description, graphics, issuer_id, medal_id, reason, status, title].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @corporation_id.nil?
    invalid_properties.push('invalid value for "corporation_id", corporation_id cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @graphics.nil?
    invalid_properties.push('invalid value for "graphics", graphics cannot be nil.')
  end

  if @issuer_id.nil?
    invalid_properties.push('invalid value for "issuer_id", issuer_id cannot be nil.')
  end

  if @medal_id.nil?
    invalid_properties.push('invalid value for "medal_id", medal_id cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/ruby-esi/models/characters_character_id_medals_get_inner.rb', line 223

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @corporation_id.nil?
  return false if @date.nil?
  return false if @description.nil?
  return false if @graphics.nil?
  return false if @issuer_id.nil?
  return false if @medal_id.nil?
  return false if @reason.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["public", "private"])
  return false unless status_validator.valid?(@status)
  return false if @title.nil?
  true
end