Class: ESI::CharactersCharacterIdOrdersGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_orders_get_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdOrdersGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdOrdersGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdOrdersGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  else
    self.duration = nil
  end

  if attributes.key?(:'escrow')
    self.escrow = attributes[:'escrow']
  end

  if attributes.key?(:'is_buy_order')
    self.is_buy_order = attributes[:'is_buy_order']
  end

  if attributes.key?(:'is_corporation')
    self.is_corporation = attributes[:'is_corporation']
  else
    self.is_corporation = nil
  end

  if attributes.key?(:'issued')
    self.issued = attributes[:'issued']
  else
    self.issued = nil
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  else
    self.location_id = nil
  end

  if attributes.key?(:'min_volume')
    self.min_volume = attributes[:'min_volume']
  end

  if attributes.key?(:'order_id')
    self.order_id = attributes[:'order_id']
  else
    self.order_id = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  else
    self.price = nil
  end

  if attributes.key?(:'range')
    self.range = attributes[:'range']
  else
    self.range = nil
  end

  if attributes.key?(:'region_id')
    self.region_id = attributes[:'region_id']
  else
    self.region_id = nil
  end

  if attributes.key?(:'type_id')
    self.type_id = attributes[:'type_id']
  else
    self.type_id = nil
  end

  if attributes.key?(:'volume_remain')
    self.volume_remain = attributes[:'volume_remain']
  else
    self.volume_remain = nil
  end

  if attributes.key?(:'volume_total')
    self.volume_total = attributes[:'volume_total']
  else
    self.volume_total = nil
  end
end

Instance Attribute Details

#durationObject

Number of days for which order is valid (starting from the issued date). An order expires at time issued + duration



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 19

def duration
  @duration
end

#escrowObject

For buy orders, the amount of ISK in escrow



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 22

def escrow
  @escrow
end

#is_buy_orderObject

True if the order is a bid (buy) order



25
26
27
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 25

def is_buy_order
  @is_buy_order
end

#is_corporationObject

Signifies whether the buy/sell order was placed on behalf of a corporation.



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 28

def is_corporation
  @is_corporation
end

#issuedObject

Date and time when this order was issued



31
32
33
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 31

def issued
  @issued
end

#location_idObject

ID of the location where order was placed



34
35
36
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 34

def location_id
  @location_id
end

#min_volumeObject

For buy orders, the minimum quantity that will be accepted in a matching sell order



37
38
39
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 37

def min_volume
  @min_volume
end

#order_idObject

Unique order ID



40
41
42
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 40

def order_id
  @order_id
end

#priceObject

Cost per unit for this order



43
44
45
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 43

def price
  @price
end

#rangeObject

Valid order range, numbers are ranges in jumps



46
47
48
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 46

def range
  @range
end

#region_idObject

ID of the region where order was placed



49
50
51
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 49

def region_id
  @region_id
end

#type_idObject

The type ID of the item transacted in this order



52
53
54
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 52

def type_id
  @type_id
end

#volume_remainObject

Quantity of items still required or offered



55
56
57
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 55

def volume_remain
  @volume_remain
end

#volume_totalObject

Quantity of items required or offered at time order was placed



58
59
60
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 58

def volume_total
  @volume_total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



103
104
105
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 103

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 108

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 83

def self.attribute_map
  {
    :'duration' => :'duration',
    :'escrow' => :'escrow',
    :'is_buy_order' => :'is_buy_order',
    :'is_corporation' => :'is_corporation',
    :'issued' => :'issued',
    :'location_id' => :'location_id',
    :'min_volume' => :'min_volume',
    :'order_id' => :'order_id',
    :'price' => :'price',
    :'range' => :'range',
    :'region_id' => :'region_id',
    :'type_id' => :'type_id',
    :'volume_remain' => :'volume_remain',
    :'volume_total' => :'volume_total'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 451

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 133

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 113

def self.openapi_types
  {
    :'duration' => :'Integer',
    :'escrow' => :'Float',
    :'is_buy_order' => :'Boolean',
    :'is_corporation' => :'Boolean',
    :'issued' => :'Time',
    :'location_id' => :'Integer',
    :'min_volume' => :'Integer',
    :'order_id' => :'Integer',
    :'price' => :'Float',
    :'range' => :'String',
    :'region_id' => :'Integer',
    :'type_id' => :'Integer',
    :'volume_remain' => :'Integer',
    :'volume_total' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 417

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      duration == o.duration &&
      escrow == o.escrow &&
      is_buy_order == o.is_buy_order &&
      is_corporation == o.is_corporation &&
      issued == o.issued &&
      location_id == o.location_id &&
      min_volume == o.min_volume &&
      order_id == o.order_id &&
      price == o.price &&
      range == o.range &&
      region_id == o.region_id &&
      type_id == o.type_id &&
      volume_remain == o.volume_remain &&
      volume_total == o.volume_total
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


438
439
440
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 438

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



444
445
446
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 444

def hash
  [duration, escrow, is_buy_order, is_corporation, issued, location_id, min_volume, order_id, price, range, region_id, type_id, volume_remain, volume_total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 235

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @duration.nil?
    invalid_properties.push('invalid value for "duration", duration cannot be nil.')
  end

  if @is_corporation.nil?
    invalid_properties.push('invalid value for "is_corporation", is_corporation cannot be nil.')
  end

  if @issued.nil?
    invalid_properties.push('invalid value for "issued", issued cannot be nil.')
  end

  if @location_id.nil?
    invalid_properties.push('invalid value for "location_id", location_id cannot be nil.')
  end

  if @order_id.nil?
    invalid_properties.push('invalid value for "order_id", order_id cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @range.nil?
    invalid_properties.push('invalid value for "range", range cannot be nil.')
  end

  if @region_id.nil?
    invalid_properties.push('invalid value for "region_id", region_id cannot be nil.')
  end

  if @type_id.nil?
    invalid_properties.push('invalid value for "type_id", type_id cannot be nil.')
  end

  if @volume_remain.nil?
    invalid_properties.push('invalid value for "volume_remain", volume_remain cannot be nil.')
  end

  if @volume_total.nil?
    invalid_properties.push('invalid value for "volume_total", volume_total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 473

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/ruby-esi/models/characters_character_id_orders_get_inner.rb', line 287

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @duration.nil?
  return false if @is_corporation.nil?
  return false if @issued.nil?
  return false if @location_id.nil?
  return false if @order_id.nil?
  return false if @price.nil?
  return false if @range.nil?
  range_validator = EnumAttributeValidator.new('String', ["1", "10", "2", "20", "3", "30", "4", "40", "5", "region", "solarsystem", "station"])
  return false unless range_validator.valid?(@range)
  return false if @region_id.nil?
  return false if @type_id.nil?
  return false if @volume_remain.nil?
  return false if @volume_total.nil?
  true
end