Class: ESI::CharactersCharacterIdWalletJournalGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdWalletJournalGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdWalletJournalGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdWalletJournalGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'balance')
    self.balance = attributes[:'balance']
  end

  if attributes.key?(:'context_id')
    self.context_id = attributes[:'context_id']
  end

  if attributes.key?(:'context_id_type')
    self.context_id_type = attributes[:'context_id_type']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'first_party_id')
    self.first_party_id = attributes[:'first_party_id']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'ref_type')
    self.ref_type = attributes[:'ref_type']
  else
    self.ref_type = nil
  end

  if attributes.key?(:'second_party_id')
    self.second_party_id = attributes[:'second_party_id']
  end

  if attributes.key?(:'tax')
    self.tax = attributes[:'tax']
  end

  if attributes.key?(:'tax_receiver_id')
    self.tax_receiver_id = attributes[:'tax_receiver_id']
  end
end

Instance Attribute Details

#amountObject

The amount of ISK given or taken from the wallet as a result of the given transaction. Positive when ISK is deposited into the wallet and negative when ISK is withdrawn



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 19

def amount
  @amount
end

#balanceObject

Wallet balance after transaction occurred



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 22

def balance
  @balance
end

#context_idObject

An ID that gives extra context to the particular transaction. Because of legacy reasons the context is completely different per ref_type and means different things. It is also possible to not have a context_id



25
26
27
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 25

def context_id
  @context_id
end

#context_id_typeObject

The type of the given context_id if present



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 28

def context_id_type
  @context_id_type
end

#dateObject

Date and time of transaction



31
32
33
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 31

def date
  @date
end

#descriptionObject

The reason for the transaction, mirrors what is seen in the client



34
35
36
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 34

def description
  @description
end

#first_party_idObject

The id of the first party involved in the transaction. This attribute has no consistency and is different or non existant for particular ref_types. The description attribute will help make sense of what this attribute means. For more info about the given ID it can be dropped into the /universe/names/ ESI route to determine its type and name



37
38
39
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 37

def first_party_id
  @first_party_id
end

#idObject

Unique journal reference ID



40
41
42
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 40

def id
  @id
end

#reasonObject

The user stated reason for the transaction. Only applies to some ref_types



43
44
45
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 43

def reason
  @reason
end

#ref_typeObject

\“The transaction type for the given. transaction. Different transaction types will populate different attributes.\”



46
47
48
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 46

def ref_type
  @ref_type
end

#second_party_idObject

The id of the second party involved in the transaction. This attribute has no consistency and is different or non existant for particular ref_types. The description attribute will help make sense of what this attribute means. For more info about the given ID it can be dropped into the /universe/names/ ESI route to determine its type and name



49
50
51
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 49

def second_party_id
  @second_party_id
end

#taxObject

Tax amount received. Only applies to tax related transactions



52
53
54
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 52

def tax
  @tax
end

#tax_receiver_idObject

The corporation ID receiving any tax paid. Only applies to tax related transactions



55
56
57
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 55

def tax_receiver_id
  @tax_receiver_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 80

def self.attribute_map
  {
    :'amount' => :'amount',
    :'balance' => :'balance',
    :'context_id' => :'context_id',
    :'context_id_type' => :'context_id_type',
    :'date' => :'date',
    :'description' => :'description',
    :'first_party_id' => :'first_party_id',
    :'id' => :'id',
    :'reason' => :'reason',
    :'ref_type' => :'ref_type',
    :'second_party_id' => :'second_party_id',
    :'tax' => :'tax',
    :'tax_receiver_id' => :'tax_receiver_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 334

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 109

def self.openapi_types
  {
    :'amount' => :'Float',
    :'balance' => :'Float',
    :'context_id' => :'Integer',
    :'context_id_type' => :'String',
    :'date' => :'Time',
    :'description' => :'String',
    :'first_party_id' => :'Integer',
    :'id' => :'Integer',
    :'reason' => :'String',
    :'ref_type' => :'String',
    :'second_party_id' => :'Integer',
    :'tax' => :'Float',
    :'tax_receiver_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      balance == o.balance &&
      context_id == o.context_id &&
      context_id_type == o.context_id_type &&
      date == o.date &&
      description == o.description &&
      first_party_id == o.first_party_id &&
      id == o.id &&
      reason == o.reason &&
      ref_type == o.ref_type &&
      second_party_id == o.second_party_id &&
      tax == o.tax &&
      tax_receiver_id == o.tax_receiver_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


321
322
323
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 321

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



327
328
329
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 327

def hash
  [amount, balance, context_id, context_id_type, date, description, first_party_id, id, reason, ref_type, second_party_id, tax, tax_receiver_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 212

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @ref_type.nil?
    invalid_properties.push('invalid value for "ref_type", ref_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 356

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/ruby-esi/models/characters_character_id_wallet_journal_get_inner.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  context_id_type_validator = EnumAttributeValidator.new('String', ["structure_id", "station_id", "market_transaction_id", "character_id", "corporation_id", "alliance_id", "eve_system", "industry_job_id", "contract_id", "planet_id", "system_id", "type_id"])
  return false unless context_id_type_validator.valid?(@context_id_type)
  return false if @date.nil?
  return false if @description.nil?
  return false if @id.nil?
  return false if @ref_type.nil?
  ref_type_validator = EnumAttributeValidator.new('String', ["acceleration_gate_fee", "advertisement_listing_fee", "agent_donation", "agent_location_services", "agent_miscellaneous", "agent_mission_collateral_paid", "agent_mission_collateral_refunded", "agent_mission_reward", "agent_mission_reward_corporation_tax", "agent_mission_time_bonus_reward", "agent_mission_time_bonus_reward_corporation_tax", "agent_security_services", "agent_services_rendered", "agents_preward", "air_career_program_reward", "alliance_maintainance_fee", "alliance_registration_fee", "allignment_based_gate_toll", "asset_safety_recovery_tax", "bounty", "bounty_prize", "bounty_prize_corporation_tax", "bounty_prizes", "bounty_reimbursement", "bounty_surcharge", "brokers_fee", "clone_activation", "clone_transfer", "contraband_fine", "contract_auction_bid", "contract_auction_bid_corp", "contract_auction_bid_refund", "contract_auction_sold", "contract_brokers_fee", "contract_brokers_fee_corp", "contract_collateral", "contract_collateral_deposited_corp", "contract_collateral_payout", "contract_collateral_refund", "contract_deposit", "contract_deposit_corp", "contract_deposit_refund", "contract_deposit_sales_tax", "contract_price", "contract_price_payment_corp", "contract_reversal", "contract_reward", "contract_reward_deposited", "contract_reward_deposited_corp", "contract_reward_refund", "contract_sales_tax", "copying", "corporate_reward_payout", "corporate_reward_tax", "corporation_account_withdrawal", "corporation_bulk_payment", "corporation_dividend_payment", "corporation_liquidation", "corporation_logo_change_cost", "corporation_payment", "corporation_registration_fee", "cosmetic_market_component_item_purchase", "cosmetic_market_skin_purchase", "cosmetic_market_skin_sale", "cosmetic_market_skin_sale_broker_fee", "cosmetic_market_skin_sale_tax", "cosmetic_market_skin_transaction", "courier_mission_escrow", "cspa", "cspaofflinerefund", "daily_challenge_reward", "daily_goal_payouts", "daily_goal_payouts_tax", "datacore_fee", "dna_modification_fee", "docking_fee", "duel_wager_escrow", "duel_wager_payment", "duel_wager_refund", "ess_escrow_transfer", "external_trade_delivery", "external_trade_freeze", "external_trade_thaw", "factory_slot_rental_fee", "flux_payout", "flux_tax", "flux_ticket_repayment", "flux_ticket_sale", "freelance_jobs_broadcasting_fee", "freelance_jobs_duration_fee", "freelance_jobs_escrow_refund", "freelance_jobs_reward", "freelance_jobs_reward_corporation_tax", "freelance_jobs_reward_escrow", "gm_cash_transfer", "gm_plex_fee_refund", "industry_job_tax", "infrastructure_hub_maintenance", "inheritance", "insurance", "insurgency_corruption_contribution_reward", "insurgency_suppression_contribution_reward", "item_trader_payment", "jump_clone_activation_fee", "jump_clone_installation_fee", "kill_right_fee", "lp_store", "manufacturing", "market_escrow", "market_fine_paid", "market_provider_tax", "market_transaction", "medal_creation", "medal_issued", "milestone_reward_payment", "mission_completion", "mission_cost", "mission_expiration", "mission_reward", "office_rental_fee", "operation_bonus", "opportunity_reward", "planetary_construction", "planetary_export_tax", "planetary_import_tax", "player_donation", "player_trading", "project_discovery_reward", "project_discovery_tax", "project_payouts", "reaction", "redeemed_isk_token", "release_of_impounded_property", "repair_bill", "reprocessing_tax", "researching_material_productivity", "researching_technology", "researching_time_productivity", "resource_wars_reward", "reverse_engineering", "season_challenge_reward", "security_processing_fee", "shares", "skill_purchase", "skyhook_claim_fee", "sovereignity_bill", "store_purchase", "store_purchase_refund", "structure_gate_jump", "transaction_tax", "under_construction", "upkeep_adjustment_fee", "war_ally_contract", "war_fee", "war_fee_surrender"])
  return false unless ref_type_validator.valid?(@ref_type)
  true
end