Class: ESI::CharactersCharacterIdWalletTransactionsGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb

Overview

wallet transaction

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CharactersCharacterIdWalletTransactionsGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdWalletTransactionsGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdWalletTransactionsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  else
    self.client_id = nil
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'is_buy')
    self.is_buy = attributes[:'is_buy']
  else
    self.is_buy = nil
  end

  if attributes.key?(:'is_personal')
    self.is_personal = attributes[:'is_personal']
  else
    self.is_personal = nil
  end

  if attributes.key?(:'journal_ref_id')
    self.journal_ref_id = attributes[:'journal_ref_id']
  else
    self.journal_ref_id = nil
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  else
    self.location_id = nil
  end

  if attributes.key?(:'quantity')
    self.quantity = attributes[:'quantity']
  else
    self.quantity = nil
  end

  if attributes.key?(:'transaction_id')
    self.transaction_id = attributes[:'transaction_id']
  else
    self.transaction_id = nil
  end

  if attributes.key?(:'type_id')
    self.type_id = attributes[:'type_id']
  else
    self.type_id = nil
  end

  if attributes.key?(:'unit_price')
    self.unit_price = attributes[:'unit_price']
  else
    self.unit_price = nil
  end
end

Instance Attribute Details

#client_idObject

Returns the value of attribute client_id.



19
20
21
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 19

def client_id
  @client_id
end

#dateObject

Date and time of transaction



22
23
24
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 22

def date
  @date
end

#is_buyObject

Returns the value of attribute is_buy.



24
25
26
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 24

def is_buy
  @is_buy
end

#is_personalObject

Returns the value of attribute is_personal.



26
27
28
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 26

def is_personal
  @is_personal
end

#journal_ref_idObject

Returns the value of attribute journal_ref_id.



28
29
30
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 28

def journal_ref_id
  @journal_ref_id
end

#location_idObject

Returns the value of attribute location_id.



30
31
32
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 30

def location_id
  @location_id
end

#quantityObject

Returns the value of attribute quantity.



32
33
34
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 32

def quantity
  @quantity
end

#transaction_idObject

Unique transaction ID



35
36
37
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 35

def transaction_id
  @transaction_id
end

#type_idObject

Returns the value of attribute type_id.



37
38
39
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 37

def type_id
  @type_id
end

#unit_priceObject

Amount paid per unit



40
41
42
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 40

def unit_price
  @unit_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 43

def self.attribute_map
  {
    :'client_id' => :'client_id',
    :'date' => :'date',
    :'is_buy' => :'is_buy',
    :'is_personal' => :'is_personal',
    :'journal_ref_id' => :'journal_ref_id',
    :'location_id' => :'location_id',
    :'quantity' => :'quantity',
    :'transaction_id' => :'transaction_id',
    :'type_id' => :'type_id',
    :'unit_price' => :'unit_price'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 364

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 69

def self.openapi_types
  {
    :'client_id' => :'Integer',
    :'date' => :'Time',
    :'is_buy' => :'Boolean',
    :'is_personal' => :'Boolean',
    :'journal_ref_id' => :'Integer',
    :'location_id' => :'Integer',
    :'quantity' => :'Integer',
    :'transaction_id' => :'Integer',
    :'type_id' => :'Integer',
    :'unit_price' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 334

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_id == o.client_id &&
      date == o.date &&
      is_buy == o.is_buy &&
      is_personal == o.is_personal &&
      journal_ref_id == o.journal_ref_id &&
      location_id == o.location_id &&
      quantity == o.quantity &&
      transaction_id == o.transaction_id &&
      type_id == o.type_id &&
      unit_price == o.unit_price
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 351

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



357
358
359
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 357

def hash
  [client_id, date, is_buy, is_personal, journal_ref_id, location_id, quantity, transaction_id, type_id, unit_price].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @client_id.nil?
    invalid_properties.push('invalid value for "client_id", client_id cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @is_buy.nil?
    invalid_properties.push('invalid value for "is_buy", is_buy cannot be nil.')
  end

  if @is_personal.nil?
    invalid_properties.push('invalid value for "is_personal", is_personal cannot be nil.')
  end

  if @journal_ref_id.nil?
    invalid_properties.push('invalid value for "journal_ref_id", journal_ref_id cannot be nil.')
  end

  if @location_id.nil?
    invalid_properties.push('invalid value for "location_id", location_id cannot be nil.')
  end

  if @quantity.nil?
    invalid_properties.push('invalid value for "quantity", quantity cannot be nil.')
  end

  if @transaction_id.nil?
    invalid_properties.push('invalid value for "transaction_id", transaction_id cannot be nil.')
  end

  if @type_id.nil?
    invalid_properties.push('invalid value for "type_id", type_id cannot be nil.')
  end

  if @unit_price.nil?
    invalid_properties.push('invalid value for "unit_price", unit_price cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/ruby-esi/models/characters_character_id_wallet_transactions_get_inner.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @client_id.nil?
  return false if @date.nil?
  return false if @is_buy.nil?
  return false if @is_personal.nil?
  return false if @journal_ref_id.nil?
  return false if @location_id.nil?
  return false if @quantity.nil?
  return false if @transaction_id.nil?
  return false if @type_id.nil?
  return false if @unit_price.nil?
  true
end