Class: ESI::DogmaAttributesAttributeIdGet

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DogmaAttributesAttributeIdGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::DogmaAttributesAttributeIdGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::DogmaAttributesAttributeIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attribute_id')
    self.attribute_id = attributes[:'attribute_id']
  else
    self.attribute_id = nil
  end

  if attributes.key?(:'default_value')
    self.default_value = attributes[:'default_value']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'high_is_good')
    self.high_is_good = attributes[:'high_is_good']
  end

  if attributes.key?(:'icon_id')
    self.icon_id = attributes[:'icon_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'published')
    self.published = attributes[:'published']
  end

  if attributes.key?(:'stackable')
    self.stackable = attributes[:'stackable']
  end

  if attributes.key?(:'unit_id')
    self.unit_id = attributes[:'unit_id']
  end
end

Instance Attribute Details

#attribute_idObject

Returns the value of attribute attribute_id.



18
19
20
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 18

def attribute_id
  @attribute_id
end

#default_valueObject

Returns the value of attribute default_value.



20
21
22
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 20

def default_value
  @default_value
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 22

def description
  @description
end

#display_nameObject

Returns the value of attribute display_name.



24
25
26
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 24

def display_name
  @display_name
end

#high_is_goodObject

Returns the value of attribute high_is_good.



26
27
28
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 26

def high_is_good
  @high_is_good
end

#icon_idObject

Returns the value of attribute icon_id.



28
29
30
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 28

def icon_id
  @icon_id
end

#nameObject

Returns the value of attribute name.



30
31
32
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 30

def name
  @name
end

#publishedObject

Returns the value of attribute published.



32
33
34
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 32

def published
  @published
end

#stackableObject

Returns the value of attribute stackable.



34
35
36
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 34

def stackable
  @stackable
end

#unit_idObject

Returns the value of attribute unit_id.



36
37
38
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 36

def unit_id
  @unit_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 39

def self.attribute_map
  {
    :'attribute_id' => :'attribute_id',
    :'default_value' => :'default_value',
    :'description' => :'description',
    :'display_name' => :'display_name',
    :'high_is_good' => :'high_is_good',
    :'icon_id' => :'icon_id',
    :'name' => :'name',
    :'published' => :'published',
    :'stackable' => :'stackable',
    :'unit_id' => :'unit_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 207

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 65

def self.openapi_types
  {
    :'attribute_id' => :'Integer',
    :'default_value' => :'Float',
    :'description' => :'String',
    :'display_name' => :'String',
    :'high_is_good' => :'Boolean',
    :'icon_id' => :'Integer',
    :'name' => :'String',
    :'published' => :'Boolean',
    :'stackable' => :'Boolean',
    :'unit_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attribute_id == o.attribute_id &&
      default_value == o.default_value &&
      description == o.description &&
      display_name == o.display_name &&
      high_is_good == o.high_is_good &&
      icon_id == o.icon_id &&
      name == o.name &&
      published == o.published &&
      stackable == o.stackable &&
      unit_id == o.unit_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 200

def hash
  [attribute_id, default_value, description, display_name, high_is_good, icon_id, name, published, stackable, unit_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @attribute_id.nil?
    invalid_properties.push('invalid value for "attribute_id", attribute_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



159
160
161
162
163
# File 'lib/ruby-esi/models/dogma_attributes_attribute_id_get.rb', line 159

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @attribute_id.nil?
  true
end