Class: ESI::DogmaDynamicItemsTypeIdItemIdGet

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DogmaDynamicItemsTypeIdItemIdGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::DogmaDynamicItemsTypeIdItemIdGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::DogmaDynamicItemsTypeIdItemIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  else
    self.created_by = nil
  end

  if attributes.key?(:'dogma_attributes')
    if (value = attributes[:'dogma_attributes']).is_a?(Array)
      self.dogma_attributes = value
    end
  else
    self.dogma_attributes = nil
  end

  if attributes.key?(:'dogma_effects')
    if (value = attributes[:'dogma_effects']).is_a?(Array)
      self.dogma_effects = value
    end
  else
    self.dogma_effects = nil
  end

  if attributes.key?(:'mutator_type_id')
    self.mutator_type_id = attributes[:'mutator_type_id']
  else
    self.mutator_type_id = nil
  end

  if attributes.key?(:'source_type_id')
    self.source_type_id = attributes[:'source_type_id']
  else
    self.source_type_id = nil
  end
end

Instance Attribute Details

#created_byObject

The ID of the character who created the item



19
20
21
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 19

def created_by
  @created_by
end

#dogma_attributesObject

Returns the value of attribute dogma_attributes.



21
22
23
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 21

def dogma_attributes
  @dogma_attributes
end

#dogma_effectsObject

Returns the value of attribute dogma_effects.



23
24
25
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 23

def dogma_effects
  @dogma_effects
end

#mutator_type_idObject

The type ID of the mutator used to generate the dynamic item.



26
27
28
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 26

def mutator_type_id
  @mutator_type_id
end

#source_type_idObject

The type ID of the source item the mutator was applied to create the dynamic item.



29
30
31
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 29

def source_type_id
  @source_type_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 32

def self.attribute_map
  {
    :'created_by' => :'created_by',
    :'dogma_attributes' => :'dogma_attributes',
    :'dogma_effects' => :'dogma_effects',
    :'mutator_type_id' => :'mutator_type_id',
    :'source_type_id' => :'source_type_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 53

def self.openapi_types
  {
    :'created_by' => :'Integer',
    :'dogma_attributes' => :'Array<DogmaDynamicItemsTypeIdItemIdGetDogmaAttributesInner>',
    :'dogma_effects' => :'Array<DogmaDynamicItemsTypeIdItemIdGetDogmaEffectsInner>',
    :'mutator_type_id' => :'Integer',
    :'source_type_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_by == o.created_by &&
      dogma_attributes == o.dogma_attributes &&
      dogma_effects == o.dogma_effects &&
      mutator_type_id == o.mutator_type_id &&
      source_type_id == o.source_type_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 230

def hash
  [created_by, dogma_attributes, dogma_effects, mutator_type_id, source_type_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_by.nil?
    invalid_properties.push('invalid value for "created_by", created_by cannot be nil.')
  end

  if @dogma_attributes.nil?
    invalid_properties.push('invalid value for "dogma_attributes", dogma_attributes cannot be nil.')
  end

  if @dogma_effects.nil?
    invalid_properties.push('invalid value for "dogma_effects", dogma_effects cannot be nil.')
  end

  if @mutator_type_id.nil?
    invalid_properties.push('invalid value for "mutator_type_id", mutator_type_id cannot be nil.')
  end

  if @source_type_id.nil?
    invalid_properties.push('invalid value for "source_type_id", source_type_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
157
158
# File 'lib/ruby-esi/models/dogma_dynamic_items_type_id_item_id_get.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_by.nil?
  return false if @dogma_attributes.nil?
  return false if @dogma_effects.nil?
  return false if @mutator_type_id.nil?
  return false if @source_type_id.nil?
  true
end