Class: ESI::FwStatsGetInner

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/fw_stats_get_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FwStatsGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::FwStatsGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::FwStatsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'faction_id')
    self.faction_id = attributes[:'faction_id']
  else
    self.faction_id = nil
  end

  if attributes.key?(:'kills')
    self.kills = attributes[:'kills']
  else
    self.kills = nil
  end

  if attributes.key?(:'pilots')
    self.pilots = attributes[:'pilots']
  else
    self.pilots = nil
  end

  if attributes.key?(:'systems_controlled')
    self.systems_controlled = attributes[:'systems_controlled']
  else
    self.systems_controlled = nil
  end

  if attributes.key?(:'victory_points')
    self.victory_points = attributes[:'victory_points']
  else
    self.victory_points = nil
  end
end

Instance Attribute Details

#faction_idObject

Returns the value of attribute faction_id.



18
19
20
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 18

def faction_id
  @faction_id
end

#killsObject

Returns the value of attribute kills.



20
21
22
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 20

def kills
  @kills
end

#pilotsObject

How many pilots fight for the given faction



23
24
25
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 23

def pilots
  @pilots
end

#systems_controlledObject

The number of solar systems controlled by the given faction



26
27
28
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 26

def systems_controlled
  @systems_controlled
end

#victory_pointsObject

Returns the value of attribute victory_points.



28
29
30
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 28

def victory_points
  @victory_points
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 31

def self.attribute_map
  {
    :'faction_id' => :'faction_id',
    :'kills' => :'kills',
    :'pilots' => :'pilots',
    :'systems_controlled' => :'systems_controlled',
    :'victory_points' => :'victory_points'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 232

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 52

def self.openapi_types
  {
    :'faction_id' => :'Integer',
    :'kills' => :'FwStatsGetInnerKills',
    :'pilots' => :'Integer',
    :'systems_controlled' => :'Integer',
    :'victory_points' => :'FwStatsGetInnerVictoryPoints'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      faction_id == o.faction_id &&
      kills == o.kills &&
      pilots == o.pilots &&
      systems_controlled == o.systems_controlled &&
      victory_points == o.victory_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 225

def hash
  [faction_id, kills, pilots, systems_controlled, victory_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @faction_id.nil?
    invalid_properties.push('invalid value for "faction_id", faction_id cannot be nil.')
  end

  if @kills.nil?
    invalid_properties.push('invalid value for "kills", kills cannot be nil.')
  end

  if @pilots.nil?
    invalid_properties.push('invalid value for "pilots", pilots cannot be nil.')
  end

  if @systems_controlled.nil?
    invalid_properties.push('invalid value for "systems_controlled", systems_controlled cannot be nil.')
  end

  if @victory_points.nil?
    invalid_properties.push('invalid value for "victory_points", victory_points cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
152
153
# File 'lib/ruby-esi/models/fw_stats_get_inner.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @faction_id.nil?
  return false if @kills.nil?
  return false if @pilots.nil?
  return false if @systems_controlled.nil?
  return false if @victory_points.nil?
  true
end