Class: ESI::KillmailsKillmailIdKillmailHashGet

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KillmailsKillmailIdKillmailHashGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::KillmailsKillmailIdKillmailHashGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::KillmailsKillmailIdKillmailHashGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'attackers')
    if (value = attributes[:'attackers']).is_a?(Array)
      self.attackers = value
    end
  else
    self.attackers = nil
  end

  if attributes.key?(:'killmail_id')
    self.killmail_id = attributes[:'killmail_id']
  else
    self.killmail_id = nil
  end

  if attributes.key?(:'killmail_time')
    self.killmail_time = attributes[:'killmail_time']
  else
    self.killmail_time = nil
  end

  if attributes.key?(:'moon_id')
    self.moon_id = attributes[:'moon_id']
  end

  if attributes.key?(:'solar_system_id')
    self.solar_system_id = attributes[:'solar_system_id']
  else
    self.solar_system_id = nil
  end

  if attributes.key?(:'victim')
    self.victim = attributes[:'victim']
  else
    self.victim = nil
  end

  if attributes.key?(:'war_id')
    self.war_id = attributes[:'war_id']
  end
end

Instance Attribute Details

#attackersObject

Returns the value of attribute attackers.



18
19
20
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 18

def attackers
  @attackers
end

#killmail_idObject

ID of the killmail



21
22
23
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 21

def killmail_id
  @killmail_id
end

#killmail_timeObject

Time that the victim was killed and the killmail generated



24
25
26
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 24

def killmail_time
  @killmail_time
end

#moon_idObject

Moon if the kill took place at one



27
28
29
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 27

def moon_id
  @moon_id
end

#solar_system_idObject

Solar system that the kill took place in



30
31
32
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 30

def solar_system_id
  @solar_system_id
end

#victimObject

Returns the value of attribute victim.



32
33
34
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 32

def victim
  @victim
end

#war_idObject

War if the killmail is generated in relation to an official war



35
36
37
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 35

def war_id
  @war_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 38

def self.attribute_map
  {
    :'attackers' => :'attackers',
    :'killmail_id' => :'killmail_id',
    :'killmail_time' => :'killmail_time',
    :'moon_id' => :'moon_id',
    :'solar_system_id' => :'solar_system_id',
    :'victim' => :'victim',
    :'war_id' => :'war_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 61

def self.openapi_types
  {
    :'attackers' => :'Array<KillmailsKillmailIdKillmailHashGetAttackersInner>',
    :'killmail_id' => :'Integer',
    :'killmail_time' => :'Time',
    :'moon_id' => :'Integer',
    :'solar_system_id' => :'Integer',
    :'victim' => :'KillmailsKillmailIdKillmailHashGetVictim',
    :'war_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      attackers == o.attackers &&
      killmail_id == o.killmail_id &&
      killmail_time == o.killmail_time &&
      moon_id == o.moon_id &&
      solar_system_id == o.solar_system_id &&
      victim == o.victim &&
      war_id == o.war_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 248

def hash
  [attackers, killmail_id, killmail_time, moon_id, solar_system_id, victim, war_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @attackers.nil?
    invalid_properties.push('invalid value for "attackers", attackers cannot be nil.')
  end

  if @killmail_id.nil?
    invalid_properties.push('invalid value for "killmail_id", killmail_id cannot be nil.')
  end

  if @killmail_time.nil?
    invalid_properties.push('invalid value for "killmail_time", killmail_time cannot be nil.')
  end

  if @solar_system_id.nil?
    invalid_properties.push('invalid value for "solar_system_id", solar_system_id cannot be nil.')
  end

  if @victim.nil?
    invalid_properties.push('invalid value for "victim", victim cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 277

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
174
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @attackers.nil?
  return false if @killmail_id.nil?
  return false if @killmail_time.nil?
  return false if @solar_system_id.nil?
  return false if @victim.nil?
  true
end