Class: ESI::KillmailsKillmailIdKillmailHashGetVictimItemsInnerItemsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb

Overview

item object

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KillmailsKillmailIdKillmailHashGetVictimItemsInnerItemsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::KillmailsKillmailIdKillmailHashGetVictimItemsInnerItemsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::KillmailsKillmailIdKillmailHashGetVictimItemsInnerItemsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flag')
    self.flag = attributes[:'flag']
  else
    self.flag = nil
  end

  if attributes.key?(:'item_type_id')
    self.item_type_id = attributes[:'item_type_id']
  else
    self.item_type_id = nil
  end

  if attributes.key?(:'quantity_destroyed')
    self.quantity_destroyed = attributes[:'quantity_destroyed']
  end

  if attributes.key?(:'quantity_dropped')
    self.quantity_dropped = attributes[:'quantity_dropped']
  end

  if attributes.key?(:'singleton')
    self.singleton = attributes[:'singleton']
  else
    self.singleton = nil
  end
end

Instance Attribute Details

#flagObject

Returns the value of attribute flag.



19
20
21
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 19

def flag
  @flag
end

#item_type_idObject

Returns the value of attribute item_type_id.



21
22
23
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 21

def item_type_id
  @item_type_id
end

#quantity_destroyedObject

Returns the value of attribute quantity_destroyed.



23
24
25
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 23

def quantity_destroyed
  @quantity_destroyed
end

#quantity_droppedObject

Returns the value of attribute quantity_dropped.



25
26
27
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 25

def quantity_dropped
  @quantity_dropped
end

#singletonObject

Returns the value of attribute singleton.



27
28
29
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 27

def singleton
  @singleton
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 30

def self.attribute_map
  {
    :'flag' => :'flag',
    :'item_type_id' => :'item_type_id',
    :'quantity_destroyed' => :'quantity_destroyed',
    :'quantity_dropped' => :'quantity_dropped',
    :'singleton' => :'singleton'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 51

def self.openapi_types
  {
    :'flag' => :'Integer',
    :'item_type_id' => :'Integer',
    :'quantity_destroyed' => :'Integer',
    :'quantity_dropped' => :'Integer',
    :'singleton' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
180
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flag == o.flag &&
      item_type_id == o.item_type_id &&
      quantity_destroyed == o.quantity_destroyed &&
      quantity_dropped == o.quantity_dropped &&
      singleton == o.singleton
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 190

def hash
  [flag, item_type_id, quantity_destroyed, quantity_dropped, singleton].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @flag.nil?
    invalid_properties.push('invalid value for "flag", flag cannot be nil.')
  end

  if @item_type_id.nil?
    invalid_properties.push('invalid value for "item_type_id", item_type_id cannot be nil.')
  end

  if @singleton.nil?
    invalid_properties.push('invalid value for "singleton", singleton cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
137
138
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim_items_inner_items_inner.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @flag.nil?
  return false if @item_type_id.nil?
  return false if @singleton.nil?
  true
end