Class: ESI::MarketsStructuresStructureIdGetInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MarketsStructuresStructureIdGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::MarketsStructuresStructureIdGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::MarketsStructuresStructureIdGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  else
    self.duration = nil
  end

  if attributes.key?(:'is_buy_order')
    self.is_buy_order = attributes[:'is_buy_order']
  else
    self.is_buy_order = nil
  end

  if attributes.key?(:'issued')
    self.issued = attributes[:'issued']
  else
    self.issued = nil
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  else
    self.location_id = nil
  end

  if attributes.key?(:'min_volume')
    self.min_volume = attributes[:'min_volume']
  else
    self.min_volume = nil
  end

  if attributes.key?(:'order_id')
    self.order_id = attributes[:'order_id']
  else
    self.order_id = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  else
    self.price = nil
  end

  if attributes.key?(:'range')
    self.range = attributes[:'range']
  else
    self.range = nil
  end

  if attributes.key?(:'type_id')
    self.type_id = attributes[:'type_id']
  else
    self.type_id = nil
  end

  if attributes.key?(:'volume_remain')
    self.volume_remain = attributes[:'volume_remain']
  else
    self.volume_remain = nil
  end

  if attributes.key?(:'volume_total')
    self.volume_total = attributes[:'volume_total']
  else
    self.volume_total = nil
  end
end

Instance Attribute Details

#durationObject

Returns the value of attribute duration.



18
19
20
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 18

def duration
  @duration
end

#is_buy_orderObject

Returns the value of attribute is_buy_order.



20
21
22
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 20

def is_buy_order
  @is_buy_order
end

#issuedObject

Returns the value of attribute issued.



22
23
24
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 22

def issued
  @issued
end

#location_idObject

Returns the value of attribute location_id.



24
25
26
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 24

def location_id
  @location_id
end

#min_volumeObject

Returns the value of attribute min_volume.



26
27
28
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 26

def min_volume
  @min_volume
end

#order_idObject

Returns the value of attribute order_id.



28
29
30
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 28

def order_id
  @order_id
end

#priceObject

Returns the value of attribute price.



30
31
32
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 30

def price
  @price
end

#rangeObject

Returns the value of attribute range.



32
33
34
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 32

def range
  @range
end

#type_idObject

Returns the value of attribute type_id.



34
35
36
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 34

def type_id
  @type_id
end

#volume_remainObject

Returns the value of attribute volume_remain.



36
37
38
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 36

def volume_remain
  @volume_remain
end

#volume_totalObject

Returns the value of attribute volume_total.



38
39
40
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 38

def volume_total
  @volume_total
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 63

def self.attribute_map
  {
    :'duration' => :'duration',
    :'is_buy_order' => :'is_buy_order',
    :'issued' => :'issued',
    :'location_id' => :'location_id',
    :'min_volume' => :'min_volume',
    :'order_id' => :'order_id',
    :'price' => :'price',
    :'range' => :'range',
    :'type_id' => :'type_id',
    :'volume_remain' => :'volume_remain',
    :'volume_total' => :'volume_total'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 410

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 90

def self.openapi_types
  {
    :'duration' => :'Integer',
    :'is_buy_order' => :'Boolean',
    :'issued' => :'Time',
    :'location_id' => :'Integer',
    :'min_volume' => :'Integer',
    :'order_id' => :'Integer',
    :'price' => :'Float',
    :'range' => :'String',
    :'type_id' => :'Integer',
    :'volume_remain' => :'Integer',
    :'volume_total' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 379

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      duration == o.duration &&
      is_buy_order == o.is_buy_order &&
      issued == o.issued &&
      location_id == o.location_id &&
      min_volume == o.min_volume &&
      order_id == o.order_id &&
      price == o.price &&
      range == o.range &&
      type_id == o.type_id &&
      volume_remain == o.volume_remain &&
      volume_total == o.volume_total
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


397
398
399
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 397

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



403
404
405
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 403

def hash
  [duration, is_buy_order, issued, location_id, min_volume, order_id, price, range, type_id, volume_remain, volume_total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 197

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @duration.nil?
    invalid_properties.push('invalid value for "duration", duration cannot be nil.')
  end

  if @is_buy_order.nil?
    invalid_properties.push('invalid value for "is_buy_order", is_buy_order cannot be nil.')
  end

  if @issued.nil?
    invalid_properties.push('invalid value for "issued", issued cannot be nil.')
  end

  if @location_id.nil?
    invalid_properties.push('invalid value for "location_id", location_id cannot be nil.')
  end

  if @min_volume.nil?
    invalid_properties.push('invalid value for "min_volume", min_volume cannot be nil.')
  end

  if @order_id.nil?
    invalid_properties.push('invalid value for "order_id", order_id cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @range.nil?
    invalid_properties.push('invalid value for "range", range cannot be nil.')
  end

  if @type_id.nil?
    invalid_properties.push('invalid value for "type_id", type_id cannot be nil.')
  end

  if @volume_remain.nil?
    invalid_properties.push('invalid value for "volume_remain", volume_remain cannot be nil.')
  end

  if @volume_total.nil?
    invalid_properties.push('invalid value for "volume_total", volume_total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 432

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/ruby-esi/models/markets_structures_structure_id_get_inner.rb', line 249

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @duration.nil?
  return false if @is_buy_order.nil?
  return false if @issued.nil?
  return false if @location_id.nil?
  return false if @min_volume.nil?
  return false if @order_id.nil?
  return false if @price.nil?
  return false if @range.nil?
  range_validator = EnumAttributeValidator.new('String', ["station", "region", "solarsystem", "1", "2", "3", "4", "5", "10", "20", "30", "40"])
  return false unless range_validator.valid?(@range)
  return false if @type_id.nil?
  return false if @volume_remain.nil?
  return false if @volume_total.nil?
  true
end