Class: ESI::MetaApi
- Inherits:
-
Object
- Object
- ESI::MetaApi
- Defined in:
- lib/ruby-esi/api/meta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_meta_changelog(x_compatibility_date, opts = {}) ⇒ MetaChangelog
Get changelog Get the changelog of this API.
-
#get_meta_changelog_with_http_info(x_compatibility_date, opts = {}) ⇒ Array<(MetaChangelog, Integer, Hash)>
Get changelog Get the changelog of this API.
-
#get_meta_compatibility_dates(x_compatibility_date, opts = {}) ⇒ MetaCompatibilityDates
Get compatibility dates Get a list of compatibility dates.
-
#get_meta_compatibility_dates_with_http_info(x_compatibility_date, opts = {}) ⇒ Array<(MetaCompatibilityDates, Integer, Hash)>
Get compatibility dates Get a list of compatibility dates.
-
#initialize(api_client = ApiClient.default) ⇒ MetaApi
constructor
A new instance of MetaApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ruby-esi/api/meta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_meta_changelog(x_compatibility_date, opts = {}) ⇒ MetaChangelog
Get changelog Get the changelog of this API.
31 32 33 34 |
# File 'lib/ruby-esi/api/meta_api.rb', line 31 def (x_compatibility_date, opts = {}) data, _status_code, _headers = (x_compatibility_date, opts) data end |
#get_meta_changelog_with_http_info(x_compatibility_date, opts = {}) ⇒ Array<(MetaChangelog, Integer, Hash)>
Get changelog Get the changelog of this API.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/ruby-esi/api/meta_api.rb', line 45 def (x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetaApi.get_meta_changelog ...' end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MetaApi.get_meta_changelog" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/meta/changelog' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MetaChangelog' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"MetaApi.get_meta_changelog", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetaApi#get_meta_changelog\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_meta_compatibility_dates(x_compatibility_date, opts = {}) ⇒ MetaCompatibilityDates
Get compatibility dates Get a list of compatibility dates.
116 117 118 119 |
# File 'lib/ruby-esi/api/meta_api.rb', line 116 def (x_compatibility_date, opts = {}) data, _status_code, _headers = (x_compatibility_date, opts) data end |
#get_meta_compatibility_dates_with_http_info(x_compatibility_date, opts = {}) ⇒ Array<(MetaCompatibilityDates, Integer, Hash)>
Get compatibility dates Get a list of compatibility dates.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/ruby-esi/api/meta_api.rb', line 130 def (x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetaApi.get_meta_compatibility_dates ...' end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MetaApi.get_meta_compatibility_dates" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/meta/compatibility-dates' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MetaCompatibilityDates' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"MetaApi.get_meta_compatibility_dates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetaApi#get_meta_compatibility_dates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |