Class: ESI::MetaChangelogEntry

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/meta_changelog_entry.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetaChangelogEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::MetaChangelogEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::MetaChangelogEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'compatibility_date')
    self.compatibility_date = attributes[:'compatibility_date']
  else
    self.compatibility_date = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'is_breaking')
    self.is_breaking = attributes[:'is_breaking']
  else
    self.is_breaking = nil
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end
end

Instance Attribute Details

#compatibility_dateObject

Compatibility date of the route



19
20
21
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 19

def compatibility_date
  @compatibility_date
end

#descriptionObject

Description



22
23
24
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 22

def description
  @description
end

#is_breakingObject

Whether this is a breaking change



25
26
27
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 25

def is_breaking
  @is_breaking
end

#methodObject

HTTP method of the route



28
29
30
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 28

def method
  @method
end

#pathObject

Path of the route



31
32
33
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 31

def path
  @path
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 56

def self.attribute_map
  {
    :'compatibility_date' => :'compatibility_date',
    :'description' => :'description',
    :'is_breaking' => :'is_breaking',
    :'method' => :'method',
    :'path' => :'path'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 77

def self.openapi_types
  {
    :'compatibility_date' => :'Date',
    :'description' => :'String',
    :'is_breaking' => :'Boolean',
    :'method' => :'String',
    :'path' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



234
235
236
237
238
239
240
241
242
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 234

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      compatibility_date == o.compatibility_date &&
      description == o.description &&
      is_breaking == o.is_breaking &&
      method == o.method &&
      path == o.path
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 252

def hash
  [compatibility_date, description, is_breaking, method, path].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @compatibility_date.nil?
    invalid_properties.push('invalid value for "compatibility_date", compatibility_date cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @is_breaking.nil?
    invalid_properties.push('invalid value for "is_breaking", is_breaking cannot be nil.')
  end

  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 281

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
179
180
# File 'lib/ruby-esi/models/meta_changelog_entry.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @compatibility_date.nil?
  return false if @description.nil?
  return false if @is_breaking.nil?
  return false if @method.nil?
  method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "DELETE"])
  return false unless method_validator.valid?(@method)
  return false if @path.nil?
  true
end