Class: ESI::PlanetaryInteractionApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby-esi/api/planetary_interaction_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PlanetaryInteractionApi

Returns a new instance of PlanetaryInteractionApi.



19
20
21
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_characters_character_id_planets(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdPlanetsGetInner>

Get colonies Returns a list of all planetary colonies owned by a character.

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



32
33
34
35
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 32

def get_characters_character_id_planets(character_id, x_compatibility_date, opts = {})
  data, _status_code, _headers = get_characters_character_id_planets_with_http_info(character_id, x_compatibility_date, opts)
  data
end

#get_characters_character_id_planets_planet_id(character_id, planet_id, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdPlanetsPlanetIdGet

Get colony layout Returns full details on the layout of a single planetary colony, including links, pins and routes. Note: Planetary information is only recalculated when the colony is viewed through the client. Information will not update until this criteria is met.

Parameters:

  • character_id (Integer)

    The ID of the character

  • planet_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



124
125
126
127
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 124

def get_characters_character_id_planets_planet_id(character_id, planet_id, x_compatibility_date, opts = {})
  data, _status_code, _headers = get_characters_character_id_planets_planet_id_with_http_info(character_id, planet_id, x_compatibility_date, opts)
  data
end

#get_characters_character_id_planets_planet_id_with_http_info(character_id, planet_id, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdPlanetsPlanetIdGet, Integer, Hash)>

Get colony layout Returns full details on the layout of a single planetary colony, including links, pins and routes. Note: Planetary information is only recalculated when the colony is viewed through the client. Information will not update until this criteria is met.

Parameters:

  • character_id (Integer)

    The ID of the character

  • planet_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 140

def get_characters_character_id_planets_planet_id_with_http_info(character_id, planet_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlanetaryInteractionApi.get_characters_character_id_planets_planet_id ...'
  end
  # verify the required parameter 'character_id' is set
  if @api_client.config.client_side_validation && character_id.nil?
    fail ArgumentError, "Missing the required parameter 'character_id' when calling PlanetaryInteractionApi.get_characters_character_id_planets_planet_id"
  end
  # verify the required parameter 'planet_id' is set
  if @api_client.config.client_side_validation && planet_id.nil?
    fail ArgumentError, "Missing the required parameter 'planet_id' when calling PlanetaryInteractionApi.get_characters_character_id_planets_planet_id"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling PlanetaryInteractionApi.get_characters_character_id_planets_planet_id"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/characters/{character_id}/planets/{planet_id}'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)).sub('{' + 'planet_id' + '}', CGI.escape(planet_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CharactersCharacterIdPlanetsPlanetIdGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"PlanetaryInteractionApi.get_characters_character_id_planets_planet_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlanetaryInteractionApi#get_characters_character_id_planets_planet_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_characters_character_id_planets_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdPlanetsGetInner>, Integer, Hash)>

Get colonies Returns a list of all planetary colonies owned by a character.

Parameters:

  • character_id (Integer)

    The ID of the character

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 47

def get_characters_character_id_planets_with_http_info(character_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlanetaryInteractionApi.get_characters_character_id_planets ...'
  end
  # verify the required parameter 'character_id' is set
  if @api_client.config.client_side_validation && character_id.nil?
    fail ArgumentError, "Missing the required parameter 'character_id' when calling PlanetaryInteractionApi.get_characters_character_id_planets"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling PlanetaryInteractionApi.get_characters_character_id_planets"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/characters/{character_id}/planets'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdPlanetsGetInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"PlanetaryInteractionApi.get_characters_character_id_planets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlanetaryInteractionApi#get_characters_character_id_planets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_corporations_corporation_id_customs_offices(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdCustomsOfficesGetInner>

List corporation customs offices List customs offices owned by a corporation

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)
  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



221
222
223
224
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 221

def get_corporations_corporation_id_customs_offices(corporation_id, x_compatibility_date, opts = {})
  data, _status_code, _headers = get_corporations_corporation_id_customs_offices_with_http_info(corporation_id, x_compatibility_date, opts)
  data
end

#get_corporations_corporation_id_customs_offices_with_http_info(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdCustomsOfficesGetInner>, Integer, Hash)>

List corporation customs offices List customs offices owned by a corporation

Parameters:

  • corporation_id (Integer)

    The ID of the corporation

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)
  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 237

def get_corporations_corporation_id_customs_offices_with_http_info(corporation_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlanetaryInteractionApi.get_corporations_corporation_id_customs_offices ...'
  end
  # verify the required parameter 'corporation_id' is set
  if @api_client.config.client_side_validation && corporation_id.nil?
    fail ArgumentError, "Missing the required parameter 'corporation_id' when calling PlanetaryInteractionApi.get_corporations_corporation_id_customs_offices"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling PlanetaryInteractionApi.get_corporations_corporation_id_customs_offices"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling PlanetaryInteractionApi.get_corporations_corporation_id_customs_offices, must be greater than or equal to 1.'
  end

  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/corporations/{corporation_id}/customs_offices'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<CorporationsCorporationIdCustomsOfficesGetInner>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"PlanetaryInteractionApi.get_corporations_corporation_id_customs_offices",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlanetaryInteractionApi#get_corporations_corporation_id_customs_offices\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_universe_schematics_schematic_id(schematic_id, x_compatibility_date, opts = {}) ⇒ UniverseSchematicsSchematicIdGet

Get schematic information Get information on a planetary factory schematic

Parameters:

  • schematic_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



318
319
320
321
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 318

def get_universe_schematics_schematic_id(schematic_id, x_compatibility_date, opts = {})
  data, _status_code, _headers = get_universe_schematics_schematic_id_with_http_info(schematic_id, x_compatibility_date, opts)
  data
end

#get_universe_schematics_schematic_id_with_http_info(schematic_id, x_compatibility_date, opts = {}) ⇒ Array<(UniverseSchematicsSchematicIdGet, Integer, Hash)>

Get schematic information Get information on a planetary factory schematic

Parameters:

  • schematic_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/ruby-esi/api/planetary_interaction_api.rb', line 333

def get_universe_schematics_schematic_id_with_http_info(schematic_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PlanetaryInteractionApi.get_universe_schematics_schematic_id ...'
  end
  # verify the required parameter 'schematic_id' is set
  if @api_client.config.client_side_validation && schematic_id.nil?
    fail ArgumentError, "Missing the required parameter 'schematic_id' when calling PlanetaryInteractionApi.get_universe_schematics_schematic_id"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling PlanetaryInteractionApi.get_universe_schematics_schematic_id"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/universe/schematics/{schematic_id}'.sub('{' + 'schematic_id' + '}', CGI.escape(schematic_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UniverseSchematicsSchematicIdGet'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"PlanetaryInteractionApi.get_universe_schematics_schematic_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PlanetaryInteractionApi#get_universe_schematics_schematic_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end