Class: ESI::PostCharactersCharacterIdMailRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/post_characters_character_id_mail_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostCharactersCharacterIdMailRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::PostCharactersCharacterIdMailRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::PostCharactersCharacterIdMailRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'approved_cost')
    self.approved_cost = attributes[:'approved_cost']
  else
    self.approved_cost = 0
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'recipients')
    if (value = attributes[:'recipients']).is_a?(Array)
      self.recipients = value
    end
  else
    self.recipients = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end
end

Instance Attribute Details

#approved_costObject

Returns the value of attribute approved_cost.



18
19
20
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 18

def approved_cost
  @approved_cost
end

#bodyObject

Returns the value of attribute body.



20
21
22
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 20

def body
  @body
end

#recipientsObject

Returns the value of attribute recipients.



22
23
24
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 22

def recipients
  @recipients
end

#subjectObject

Returns the value of attribute subject.



24
25
26
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 24

def subject
  @subject
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 27

def self.attribute_map
  {
    :'approved_cost' => :'approved_cost',
    :'body' => :'body',
    :'recipients' => :'recipients',
    :'subject' => :'subject'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 47

def self.openapi_types
  {
    :'approved_cost' => :'Integer',
    :'body' => :'String',
    :'recipients' => :'Array<PostCharactersCharacterIdMailRequestRecipientsInner>',
    :'subject' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      approved_cost == o.approved_cost &&
      body == o.body &&
      recipients == o.recipients &&
      subject == o.subject
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 220

def hash
  [approved_cost, body, recipients, subject].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 107

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @body.to_s.length > 10000
    invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 10000.')
  end

  if @recipients.nil?
    invalid_properties.push('invalid value for "recipients", recipients cannot be nil.')
  end

  if @recipients.length > 50
    invalid_properties.push('invalid value for "recipients", number of items must be less than or equal to 50.')
  end

  if @recipients.length < 1
    invalid_properties.push('invalid value for "recipients", number of items must be greater than or equal to 1.')
  end

  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  if @subject.to_s.length > 1000
    invalid_properties.push('invalid value for "subject", the character length must be smaller than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ruby-esi/models/post_characters_character_id_mail_request.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @body.nil?
  return false if @body.to_s.length > 10000
  return false if @recipients.nil?
  return false if @recipients.length > 50
  return false if @recipients.length < 1
  return false if @subject.nil?
  return false if @subject.to_s.length > 1000
  true
end