Class: ESI::PutCharactersCharacterIdMailMailIdRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PutCharactersCharacterIdMailMailIdRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 58

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::PutCharactersCharacterIdMailMailIdRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::PutCharactersCharacterIdMailMailIdRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'read')
    self.read = attributes[:'read']
  end
end

Instance Attribute Details

#labelsObject

Labels to assign to the mail. Pre-existing labels are unassigned.



19
20
21
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 19

def labels
  @labels
end

#readObject

Whether the mail is flagged as read



22
23
24
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 22

def read
  @read
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 25

def self.attribute_map
  {
    :'labels' => :'labels',
    :'read' => :'read'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 141

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 43

def self.openapi_types
  {
    :'labels' => :'Array<Integer>',
    :'read' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



119
120
121
122
123
124
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 119

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      labels == o.labels &&
      read == o.read
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


128
129
130
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 128

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



134
135
136
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 134

def hash
  [labels, read].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



85
86
87
88
89
90
91
92
93
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 85

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@labels.nil? && @labels.length > 25
    invalid_properties.push('invalid value for "labels", number of items must be less than or equal to 25.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 163

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



97
98
99
100
101
# File 'lib/ruby-esi/models/put_characters_character_id_mail_mail_id_request.rb', line 97

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@labels.nil? && @labels.length > 25
  true
end