Class: ESI::SovereigntyStructuresGetInner

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/sovereignty_structures_get_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SovereigntyStructuresGetInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::SovereigntyStructuresGetInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::SovereigntyStructuresGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'alliance_id')
    self.alliance_id = attributes[:'alliance_id']
  else
    self.alliance_id = nil
  end

  if attributes.key?(:'solar_system_id')
    self.solar_system_id = attributes[:'solar_system_id']
  else
    self.solar_system_id = nil
  end

  if attributes.key?(:'structure_id')
    self.structure_id = attributes[:'structure_id']
  else
    self.structure_id = nil
  end

  if attributes.key?(:'structure_type_id')
    self.structure_type_id = attributes[:'structure_type_id']
  else
    self.structure_type_id = nil
  end

  if attributes.key?(:'vulnerability_occupancy_level')
    self.vulnerability_occupancy_level = attributes[:'vulnerability_occupancy_level']
  end

  if attributes.key?(:'vulnerable_end_time')
    self.vulnerable_end_time = attributes[:'vulnerable_end_time']
  end

  if attributes.key?(:'vulnerable_start_time')
    self.vulnerable_start_time = attributes[:'vulnerable_start_time']
  end
end

Instance Attribute Details

#alliance_idObject

The alliance that owns the structure.



19
20
21
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 19

def alliance_id
  @alliance_id
end

#solar_system_idObject

Solar system in which the structure is located.



22
23
24
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 22

def solar_system_id
  @solar_system_id
end

#structure_idObject

Unique item ID for this structure.



25
26
27
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 25

def structure_id
  @structure_id
end

#structure_type_idObject

A reference to the type of structure this is.



28
29
30
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 28

def structure_type_id
  @structure_type_id
end

#vulnerability_occupancy_levelObject

The occupancy level for the next or current vulnerability window. This takes into account all development indexes and capital system bonuses. Also known as Activity Defense Multiplier from in the client. It increases the time that attackers must spend using their entosis links on the structure.



31
32
33
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 31

def vulnerability_occupancy_level
  @vulnerability_occupancy_level
end

#vulnerable_end_timeObject

The time at which the next or current vulnerability window ends. At the end of a vulnerability window the next window is recalculated and locked in along with the vulnerabilityOccupancyLevel. If the structure is not in 100% entosis control of the defender, it will go in to ‘overtime’ and stay vulnerable for as long as that situation persists. Only once the defenders have 100% entosis control and has the vulnerableEndTime passed does the vulnerability interval expire and a new one is calculated.



34
35
36
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 34

def vulnerable_end_time
  @vulnerable_end_time
end

#vulnerable_start_timeObject

The next time at which the structure will become vulnerable. Or the start time of the current window if current time is between this and vulnerableEndTime.



37
38
39
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 37

def vulnerable_start_time
  @vulnerable_start_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 40

def self.attribute_map
  {
    :'alliance_id' => :'alliance_id',
    :'solar_system_id' => :'solar_system_id',
    :'structure_id' => :'structure_id',
    :'structure_type_id' => :'structure_type_id',
    :'vulnerability_occupancy_level' => :'vulnerability_occupancy_level',
    :'vulnerable_end_time' => :'vulnerable_end_time',
    :'vulnerable_start_time' => :'vulnerable_start_time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 63

def self.openapi_types
  {
    :'alliance_id' => :'Integer',
    :'solar_system_id' => :'Integer',
    :'structure_id' => :'Integer',
    :'structure_type_id' => :'Integer',
    :'vulnerability_occupancy_level' => :'Float',
    :'vulnerable_end_time' => :'Time',
    :'vulnerable_start_time' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      alliance_id == o.alliance_id &&
      solar_system_id == o.solar_system_id &&
      structure_id == o.structure_id &&
      structure_type_id == o.structure_type_id &&
      vulnerability_occupancy_level == o.vulnerability_occupancy_level &&
      vulnerable_end_time == o.vulnerable_end_time &&
      vulnerable_start_time == o.vulnerable_start_time
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 231

def hash
  [alliance_id, solar_system_id, structure_id, structure_type_id, vulnerability_occupancy_level, vulnerable_end_time, vulnerable_start_time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @alliance_id.nil?
    invalid_properties.push('invalid value for "alliance_id", alliance_id cannot be nil.')
  end

  if @solar_system_id.nil?
    invalid_properties.push('invalid value for "solar_system_id", solar_system_id cannot be nil.')
  end

  if @structure_id.nil?
    invalid_properties.push('invalid value for "structure_id", structure_id cannot be nil.')
  end

  if @structure_type_id.nil?
    invalid_properties.push('invalid value for "structure_type_id", structure_type_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
# File 'lib/ruby-esi/models/sovereignty_structures_get_inner.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @alliance_id.nil?
  return false if @solar_system_id.nil?
  return false if @structure_id.nil?
  return false if @structure_type_id.nil?
  true
end