Class: ESI::UniverseStructuresStructureIdGet

Inherits:
ApiModelBase show all
Defined in:
lib/ruby-esi/models/universe_structures_structure_id_get.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UniverseStructuresStructureIdGet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::UniverseStructuresStructureIdGet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::UniverseStructuresStructureIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'owner_id')
    self.owner_id = attributes[:'owner_id']
  else
    self.owner_id = nil
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  end

  if attributes.key?(:'solar_system_id')
    self.solar_system_id = attributes[:'solar_system_id']
  else
    self.solar_system_id = nil
  end

  if attributes.key?(:'type_id')
    self.type_id = attributes[:'type_id']
  end
end

Instance Attribute Details

#nameObject

The full name of the structure



19
20
21
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 19

def name
  @name
end

#owner_idObject

The ID of the corporation who owns this particular structure



22
23
24
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 22

def owner_id
  @owner_id
end

#positionObject

Returns the value of attribute position.



24
25
26
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 24

def position
  @position
end

#solar_system_idObject

Returns the value of attribute solar_system_id.



26
27
28
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 26

def solar_system_id
  @solar_system_id
end

#type_idObject

Returns the value of attribute type_id.



28
29
30
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 28

def type_id
  @type_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 31

def self.attribute_map
  {
    :'name' => :'name',
    :'owner_id' => :'owner_id',
    :'position' => :'position',
    :'solar_system_id' => :'solar_system_id',
    :'type_id' => :'type_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 52

def self.openapi_types
  {
    :'name' => :'String',
    :'owner_id' => :'Integer',
    :'position' => :'UniverseStructuresStructureIdGetPosition',
    :'solar_system_id' => :'Integer',
    :'type_id' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      owner_id == o.owner_id &&
      position == o.position &&
      solar_system_id == o.solar_system_id &&
      type_id == o.type_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 185

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 191

def hash
  [name, owner_id, position, solar_system_id, type_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @owner_id.nil?
    invalid_properties.push('invalid value for "owner_id", owner_id cannot be nil.')
  end

  if @solar_system_id.nil?
    invalid_properties.push('invalid value for "solar_system_id", solar_system_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
139
# File 'lib/ruby-esi/models/universe_structures_structure_id_get.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @owner_id.nil?
  return false if @solar_system_id.nil?
  true
end