Class: ESI::UniverseSystemKillsGetInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::UniverseSystemKillsGetInner
- Defined in:
- lib/ruby-esi/models/universe_system_kills_get_inner.rb
Instance Attribute Summary collapse
-
#npc_kills ⇒ Object
Number of NPC ships killed in this system.
-
#pod_kills ⇒ Object
Number of pods killed in this system.
-
#ship_kills ⇒ Object
Number of player ships killed in this system.
-
#system_id ⇒ Object
Returns the value of attribute system_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UniverseSystemKillsGetInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UniverseSystemKillsGetInner
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::UniverseSystemKillsGetInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::UniverseSystemKillsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'npc_kills') self.npc_kills = attributes[:'npc_kills'] else self.npc_kills = nil end if attributes.key?(:'pod_kills') self.pod_kills = attributes[:'pod_kills'] else self.pod_kills = nil end if attributes.key?(:'ship_kills') self.ship_kills = attributes[:'ship_kills'] else self.ship_kills = nil end if attributes.key?(:'system_id') self.system_id = attributes[:'system_id'] else self.system_id = nil end end |
Instance Attribute Details
#npc_kills ⇒ Object
Number of NPC ships killed in this system
19 20 21 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 19 def npc_kills @npc_kills end |
#pod_kills ⇒ Object
Number of pods killed in this system
22 23 24 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 22 def pod_kills @pod_kills end |
#ship_kills ⇒ Object
Number of player ships killed in this system
25 26 27 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 25 def ship_kills @ship_kills end |
#system_id ⇒ Object
Returns the value of attribute system_id.
27 28 29 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 27 def system_id @system_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 30 def self.attribute_map { :'npc_kills' => :'npc_kills', :'pod_kills' => :'pod_kills', :'ship_kills' => :'ship_kills', :'system_id' => :'system_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 50 def self.openapi_types { :'npc_kills' => :'Integer', :'pod_kills' => :'Integer', :'ship_kills' => :'Integer', :'system_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && npc_kills == o.npc_kills && pod_kills == o.pod_kills && ship_kills == o.ship_kills && system_id == o.system_id end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 200 def hash [npc_kills, pod_kills, ship_kills, system_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @npc_kills.nil? invalid_properties.push('invalid value for "npc_kills", npc_kills cannot be nil.') end if @pod_kills.nil? invalid_properties.push('invalid value for "pod_kills", pod_kills cannot be nil.') end if @ship_kills.nil? invalid_properties.push('invalid value for "ship_kills", ship_kills cannot be nil.') end if @system_id.nil? invalid_properties.push('invalid value for "system_id", system_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 137 138 139 |
# File 'lib/ruby-esi/models/universe_system_kills_get_inner.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @npc_kills.nil? return false if @pod_kills.nil? return false if @ship_kills.nil? return false if @system_id.nil? true end |