Class: ESI::UserInterfaceApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby-esi/api/user_interface_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UserInterfaceApi

Returns a new instance of UserInterfaceApi.



19
20
21
# File 'lib/ruby-esi/api/user_interface_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ruby-esi/api/user_interface_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#post_ui_autopilot_waypoint(add_to_beginning, clear_other_waypoints, destination_id, x_compatibility_date, opts = {}) ⇒ nil

Set Autopilot Waypoint Set a solar system as autopilot waypoint

Parameters:

  • add_to_beginning (Boolean)
  • clear_other_waypoints (Boolean)
  • destination_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (nil)


34
35
36
37
# File 'lib/ruby-esi/api/user_interface_api.rb', line 34

def post_ui_autopilot_waypoint(add_to_beginning, clear_other_waypoints, destination_id, x_compatibility_date, opts = {})
  post_ui_autopilot_waypoint_with_http_info(add_to_beginning, clear_other_waypoints, destination_id, x_compatibility_date, opts)
  nil
end

#post_ui_autopilot_waypoint_with_http_info(add_to_beginning, clear_other_waypoints, destination_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Set Autopilot Waypoint Set a solar system as autopilot waypoint

Parameters:

  • add_to_beginning (Boolean)
  • clear_other_waypoints (Boolean)
  • destination_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/ruby-esi/api/user_interface_api.rb', line 51

def post_ui_autopilot_waypoint_with_http_info(add_to_beginning, clear_other_waypoints, destination_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserInterfaceApi.post_ui_autopilot_waypoint ...'
  end
  # verify the required parameter 'add_to_beginning' is set
  if @api_client.config.client_side_validation && add_to_beginning.nil?
    fail ArgumentError, "Missing the required parameter 'add_to_beginning' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  # verify the required parameter 'clear_other_waypoints' is set
  if @api_client.config.client_side_validation && clear_other_waypoints.nil?
    fail ArgumentError, "Missing the required parameter 'clear_other_waypoints' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  # verify the required parameter 'destination_id' is set
  if @api_client.config.client_side_validation && destination_id.nil?
    fail ArgumentError, "Missing the required parameter 'destination_id' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling UserInterfaceApi.post_ui_autopilot_waypoint"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/ui/autopilot/waypoint'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'add_to_beginning'] = add_to_beginning
  query_params[:'clear_other_waypoints'] = clear_other_waypoints
  query_params[:'destination_id'] = destination_id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserInterfaceApi.post_ui_autopilot_waypoint",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_autopilot_waypoint\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_contract(contract_id, x_compatibility_date, opts = {}) ⇒ nil

Open Contract Window Open the contract window inside the client

Parameters:

  • contract_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (nil)


138
139
140
141
# File 'lib/ruby-esi/api/user_interface_api.rb', line 138

def post_ui_openwindow_contract(contract_id, x_compatibility_date, opts = {})
  post_ui_openwindow_contract_with_http_info(contract_id, x_compatibility_date, opts)
  nil
end

#post_ui_openwindow_contract_with_http_info(contract_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Open Contract Window Open the contract window inside the client

Parameters:

  • contract_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/ruby-esi/api/user_interface_api.rb', line 153

def post_ui_openwindow_contract_with_http_info(contract_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserInterfaceApi.post_ui_openwindow_contract ...'
  end
  # verify the required parameter 'contract_id' is set
  if @api_client.config.client_side_validation && contract_id.nil?
    fail ArgumentError, "Missing the required parameter 'contract_id' when calling UserInterfaceApi.post_ui_openwindow_contract"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling UserInterfaceApi.post_ui_openwindow_contract"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/ui/openwindow/contract'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'contract_id'] = contract_id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserInterfaceApi.post_ui_openwindow_contract",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_contract\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_information(target_id, x_compatibility_date, opts = {}) ⇒ nil

Open Information Window Open the information window for a character, corporation or alliance inside the client

Parameters:

  • target_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (nil)


230
231
232
233
# File 'lib/ruby-esi/api/user_interface_api.rb', line 230

def post_ui_openwindow_information(target_id, x_compatibility_date, opts = {})
  post_ui_openwindow_information_with_http_info(target_id, x_compatibility_date, opts)
  nil
end

#post_ui_openwindow_information_with_http_info(target_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Open Information Window Open the information window for a character, corporation or alliance inside the client

Parameters:

  • target_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/ruby-esi/api/user_interface_api.rb', line 245

def post_ui_openwindow_information_with_http_info(target_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserInterfaceApi.post_ui_openwindow_information ...'
  end
  # verify the required parameter 'target_id' is set
  if @api_client.config.client_side_validation && target_id.nil?
    fail ArgumentError, "Missing the required parameter 'target_id' when calling UserInterfaceApi.post_ui_openwindow_information"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling UserInterfaceApi.post_ui_openwindow_information"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/ui/openwindow/information'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'target_id'] = target_id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserInterfaceApi.post_ui_openwindow_information",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_information\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_marketdetails(type_id, x_compatibility_date, opts = {}) ⇒ nil

Open Market Details Open the market details window for a specific typeID inside the client

Parameters:

  • type_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (nil)


322
323
324
325
# File 'lib/ruby-esi/api/user_interface_api.rb', line 322

def post_ui_openwindow_marketdetails(type_id, x_compatibility_date, opts = {})
  post_ui_openwindow_marketdetails_with_http_info(type_id, x_compatibility_date, opts)
  nil
end

#post_ui_openwindow_marketdetails_with_http_info(type_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Open Market Details Open the market details window for a specific typeID inside the client

Parameters:

  • type_id (Integer)
  • x_compatibility_date (Date)

    The compatibility date for the request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/ruby-esi/api/user_interface_api.rb', line 337

def post_ui_openwindow_marketdetails_with_http_info(type_id, x_compatibility_date, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserInterfaceApi.post_ui_openwindow_marketdetails ...'
  end
  # verify the required parameter 'type_id' is set
  if @api_client.config.client_side_validation && type_id.nil?
    fail ArgumentError, "Missing the required parameter 'type_id' when calling UserInterfaceApi.post_ui_openwindow_marketdetails"
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling UserInterfaceApi.post_ui_openwindow_marketdetails"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/ui/openwindow/marketdetails'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'type_id'] = type_id

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserInterfaceApi.post_ui_openwindow_marketdetails",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_marketdetails\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_ui_openwindow_newmail(x_compatibility_date, post_ui_openwindow_newmail_request, opts = {}) ⇒ nil

Open New Mail Window Open the New Mail window, according to settings from the request if applicable

Parameters:

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • post_ui_openwindow_newmail_request (PostUiOpenwindowNewmailRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (nil)


414
415
416
417
# File 'lib/ruby-esi/api/user_interface_api.rb', line 414

def post_ui_openwindow_newmail(x_compatibility_date, post_ui_openwindow_newmail_request, opts = {})
  post_ui_openwindow_newmail_with_http_info(x_compatibility_date, post_ui_openwindow_newmail_request, opts)
  nil
end

#post_ui_openwindow_newmail_with_http_info(x_compatibility_date, post_ui_openwindow_newmail_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Open New Mail Window Open the New Mail window, according to settings from the request if applicable

Parameters:

  • x_compatibility_date (Date)

    The compatibility date for the request.

  • post_ui_openwindow_newmail_request (PostUiOpenwindowNewmailRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :accept_language (String)

    The language to use for the response. (default to ‘en’)

  • :if_none_match (String)

    The ETag of the previous request. A 304 will be returned if this matches the current ETag.

  • :x_tenant (String)

    The tenant ID for the request. (default to ‘tranquility’)

  • :if_modified_since (String)

    The date the resource was last modified. A 304 will be returned if the resource has not been modified since this date.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/ruby-esi/api/user_interface_api.rb', line 429

def post_ui_openwindow_newmail_with_http_info(x_compatibility_date, post_ui_openwindow_newmail_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserInterfaceApi.post_ui_openwindow_newmail ...'
  end
  # verify the required parameter 'x_compatibility_date' is set
  if @api_client.config.client_side_validation && x_compatibility_date.nil?
    fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling UserInterfaceApi.post_ui_openwindow_newmail"
  end
  # verify enum value
  allowable_values = ["2020-01-01"]
  if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date)
    fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'post_ui_openwindow_newmail_request' is set
  if @api_client.config.client_side_validation && post_ui_openwindow_newmail_request.nil?
    fail ArgumentError, "Missing the required parameter 'post_ui_openwindow_newmail_request' when calling UserInterfaceApi.post_ui_openwindow_newmail"
  end
  allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"]
  if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language'])
    fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/ui/openwindow/newmail'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  header_params[:'X-Compatibility-Date'] = x_compatibility_date
  header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil?
  header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil?
  header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil?
  header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(post_ui_openwindow_newmail_request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserInterfaceApi.post_ui_openwindow_newmail",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserInterfaceApi#post_ui_openwindow_newmail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end