Class: ESI::WalletApi
- Inherits:
-
Object
- Object
- ESI::WalletApi
- Defined in:
- lib/ruby-esi/api/wallet_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_characters_character_id_wallet(character_id, x_compatibility_date, opts = {}) ⇒ Float
Get a character’s wallet balance Returns a character’s wallet balance.
-
#get_characters_character_id_wallet_journal(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdWalletJournalGetInner>
Get character wallet journal Retrieve the given character’s wallet journal going 30 days back.
-
#get_characters_character_id_wallet_journal_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdWalletJournalGetInner>, Integer, Hash)>
Get character wallet journal Retrieve the given character's wallet journal going 30 days back.
-
#get_characters_character_id_wallet_transactions(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdWalletTransactionsGetInner>
Get wallet transactions Get wallet transactions of a character.
-
#get_characters_character_id_wallet_transactions_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdWalletTransactionsGetInner>, Integer, Hash)>
Get wallet transactions Get wallet transactions of a character.
-
#get_characters_character_id_wallet_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Float, Integer, Hash)>
Get a character's wallet balance Returns a character's wallet balance.
-
#get_corporations_corporation_id_wallets(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdWalletsGetInner>
Returns a corporation’s wallet balance Get a corporation’s wallets.
-
#get_corporations_corporation_id_wallets_division_journal(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdWalletsDivisionJournalGetInner>
Get corporation wallet journal Retrieve the given corporation’s wallet journal for the given division going 30 days back.
-
#get_corporations_corporation_id_wallets_division_journal_with_http_info(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdWalletsDivisionJournalGetInner>, Integer, Hash)>
Get corporation wallet journal Retrieve the given corporation's wallet journal for the given division going 30 days back.
-
#get_corporations_corporation_id_wallets_division_transactions(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdWalletsDivisionTransactionsGetInner>
Get corporation wallet transactions Get wallet transactions of a corporation.
-
#get_corporations_corporation_id_wallets_division_transactions_with_http_info(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdWalletsDivisionTransactionsGetInner>, Integer, Hash)>
Get corporation wallet transactions Get wallet transactions of a corporation.
-
#get_corporations_corporation_id_wallets_with_http_info(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdWalletsGetInner>, Integer, Hash)>
Returns a corporation's wallet balance Get a corporation's wallets.
-
#initialize(api_client = ApiClient.default) ⇒ WalletApi
constructor
A new instance of WalletApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_characters_character_id_wallet(character_id, x_compatibility_date, opts = {}) ⇒ Float
Get a character’s wallet balance Returns a character’s wallet balance
32 33 34 35 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 32 def get_characters_character_id_wallet(character_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_wallet_with_http_info(character_id, x_compatibility_date, opts) data end |
#get_characters_character_id_wallet_journal(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdWalletJournalGetInner>
Get character wallet journal Retrieve the given character’s wallet journal going 30 days back
124 125 126 127 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 124 def get_characters_character_id_wallet_journal(character_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_wallet_journal_with_http_info(character_id, x_compatibility_date, opts) data end |
#get_characters_character_id_wallet_journal_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdWalletJournalGetInner>, Integer, Hash)>
Get character wallet journal Retrieve the given character's wallet journal going 30 days back
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 140 def get_characters_character_id_wallet_journal_with_http_info(character_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletApi.get_characters_character_id_wallet_journal ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling WalletApi.get_characters_character_id_wallet_journal" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WalletApi.get_characters_character_id_wallet_journal" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalletApi.get_characters_character_id_wallet_journal, must be greater than or equal to 1.' end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/wallet/journal'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdWalletJournalGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"WalletApi.get_characters_character_id_wallet_journal", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletApi#get_characters_character_id_wallet_journal\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_characters_character_id_wallet_transactions(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdWalletTransactionsGetInner>
Get wallet transactions Get wallet transactions of a character
222 223 224 225 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 222 def get_characters_character_id_wallet_transactions(character_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_wallet_transactions_with_http_info(character_id, x_compatibility_date, opts) data end |
#get_characters_character_id_wallet_transactions_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdWalletTransactionsGetInner>, Integer, Hash)>
Get wallet transactions Get wallet transactions of a character
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 238 def get_characters_character_id_wallet_transactions_with_http_info(character_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletApi.get_characters_character_id_wallet_transactions ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling WalletApi.get_characters_character_id_wallet_transactions" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WalletApi.get_characters_character_id_wallet_transactions" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/wallet/transactions'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'from_id'] = opts[:'from_id'] if !opts[:'from_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdWalletTransactionsGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"WalletApi.get_characters_character_id_wallet_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletApi#get_characters_character_id_wallet_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_characters_character_id_wallet_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Float, Integer, Hash)>
Get a character's wallet balance Returns a character's wallet balance
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 47 def get_characters_character_id_wallet_with_http_info(character_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletApi.get_characters_character_id_wallet ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling WalletApi.get_characters_character_id_wallet" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WalletApi.get_characters_character_id_wallet" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/wallet'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Float' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"WalletApi.get_characters_character_id_wallet", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletApi#get_characters_character_id_wallet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_corporations_corporation_id_wallets(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdWalletsGetInner>
Returns a corporation’s wallet balance Get a corporation’s wallets
315 316 317 318 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 315 def get_corporations_corporation_id_wallets(corporation_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_corporations_corporation_id_wallets_with_http_info(corporation_id, x_compatibility_date, opts) data end |
#get_corporations_corporation_id_wallets_division_journal(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdWalletsDivisionJournalGetInner>
Get corporation wallet journal Retrieve the given corporation’s wallet journal for the given division going 30 days back
408 409 410 411 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 408 def get_corporations_corporation_id_wallets_division_journal(corporation_id, division, x_compatibility_date, opts = {}) data, _status_code, _headers = get_corporations_corporation_id_wallets_division_journal_with_http_info(corporation_id, division, x_compatibility_date, opts) data end |
#get_corporations_corporation_id_wallets_division_journal_with_http_info(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdWalletsDivisionJournalGetInner>, Integer, Hash)>
Get corporation wallet journal Retrieve the given corporation's wallet journal for the given division going 30 days back
425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 425 def get_corporations_corporation_id_wallets_division_journal_with_http_info(corporation_id, division, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletApi.get_corporations_corporation_id_wallets_division_journal ...' end # verify the required parameter 'corporation_id' is set if @api_client.config.client_side_validation && corporation_id.nil? fail ArgumentError, "Missing the required parameter 'corporation_id' when calling WalletApi.get_corporations_corporation_id_wallets_division_journal" end # verify the required parameter 'division' is set if @api_client.config.client_side_validation && division.nil? fail ArgumentError, "Missing the required parameter 'division' when calling WalletApi.get_corporations_corporation_id_wallets_division_journal" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WalletApi.get_corporations_corporation_id_wallets_division_journal" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WalletApi.get_corporations_corporation_id_wallets_division_journal, must be greater than or equal to 1.' end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/corporations/{corporation_id}/wallets/{division}/journal'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s)).sub('{' + 'division' + '}', CGI.escape(division.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CorporationsCorporationIdWalletsDivisionJournalGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"WalletApi.get_corporations_corporation_id_wallets_division_journal", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletApi#get_corporations_corporation_id_wallets_division_journal\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_corporations_corporation_id_wallets_division_transactions(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<CorporationsCorporationIdWalletsDivisionTransactionsGetInner>
Get corporation wallet transactions Get wallet transactions of a corporation
512 513 514 515 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 512 def get_corporations_corporation_id_wallets_division_transactions(corporation_id, division, x_compatibility_date, opts = {}) data, _status_code, _headers = get_corporations_corporation_id_wallets_division_transactions_with_http_info(corporation_id, division, x_compatibility_date, opts) data end |
#get_corporations_corporation_id_wallets_division_transactions_with_http_info(corporation_id, division, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdWalletsDivisionTransactionsGetInner>, Integer, Hash)>
Get corporation wallet transactions Get wallet transactions of a corporation
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 529 def get_corporations_corporation_id_wallets_division_transactions_with_http_info(corporation_id, division, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletApi.get_corporations_corporation_id_wallets_division_transactions ...' end # verify the required parameter 'corporation_id' is set if @api_client.config.client_side_validation && corporation_id.nil? fail ArgumentError, "Missing the required parameter 'corporation_id' when calling WalletApi.get_corporations_corporation_id_wallets_division_transactions" end # verify the required parameter 'division' is set if @api_client.config.client_side_validation && division.nil? fail ArgumentError, "Missing the required parameter 'division' when calling WalletApi.get_corporations_corporation_id_wallets_division_transactions" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WalletApi.get_corporations_corporation_id_wallets_division_transactions" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/corporations/{corporation_id}/wallets/{division}/transactions'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s)).sub('{' + 'division' + '}', CGI.escape(division.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'from_id'] = opts[:'from_id'] if !opts[:'from_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CorporationsCorporationIdWalletsDivisionTransactionsGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"WalletApi.get_corporations_corporation_id_wallets_division_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletApi#get_corporations_corporation_id_wallets_division_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_corporations_corporation_id_wallets_with_http_info(corporation_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CorporationsCorporationIdWalletsGetInner>, Integer, Hash)>
Returns a corporation's wallet balance Get a corporation's wallets
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/ruby-esi/api/wallet_api.rb', line 330 def get_corporations_corporation_id_wallets_with_http_info(corporation_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WalletApi.get_corporations_corporation_id_wallets ...' end # verify the required parameter 'corporation_id' is set if @api_client.config.client_side_validation && corporation_id.nil? fail ArgumentError, "Missing the required parameter 'corporation_id' when calling WalletApi.get_corporations_corporation_id_wallets" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WalletApi.get_corporations_corporation_id_wallets" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/corporations/{corporation_id}/wallets'.sub('{' + 'corporation_id' + '}', CGI.escape(corporation_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CorporationsCorporationIdWalletsGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"WalletApi.get_corporations_corporation_id_wallets", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WalletApi#get_corporations_corporation_id_wallets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |