Class: ESI::CharactersCharacterIdBlueprintsGetInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdBlueprintsGetInner
- Defined in:
- lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#item_id ⇒ Object
Unique ID for this item.
-
#location_flag ⇒ Object
Type of the location_id.
-
#location_id ⇒ Object
References a station, a ship or an item_id if this blueprint is located within a container.
-
#material_efficiency ⇒ Object
Material Efficiency Level of the blueprint.
-
#quantity ⇒ Object
A range of numbers with a minimum of -2 and no maximum value where -1 is an original and -2 is a copy.
-
#runs ⇒ Object
Number of runs remaining if the blueprint is a copy, -1 if it is an original.
-
#time_efficiency ⇒ Object
Time Efficiency Level of the blueprint.
-
#type_id ⇒ Object
Returns the value of attribute type_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdBlueprintsGetInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdBlueprintsGetInner
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdBlueprintsGetInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdBlueprintsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'item_id') self.item_id = attributes[:'item_id'] else self.item_id = nil end if attributes.key?(:'location_flag') self.location_flag = attributes[:'location_flag'] else self.location_flag = nil end if attributes.key?(:'location_id') self.location_id = attributes[:'location_id'] else self.location_id = nil end if attributes.key?(:'material_efficiency') self.material_efficiency = attributes[:'material_efficiency'] else self.material_efficiency = nil end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] else self.quantity = nil end if attributes.key?(:'runs') self.runs = attributes[:'runs'] else self.runs = nil end if attributes.key?(:'time_efficiency') self.time_efficiency = attributes[:'time_efficiency'] else self.time_efficiency = nil end if attributes.key?(:'type_id') self.type_id = attributes[:'type_id'] else self.type_id = nil end end |
Instance Attribute Details
#item_id ⇒ Object
Unique ID for this item.
19 20 21 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 19 def item_id @item_id end |
#location_flag ⇒ Object
Type of the location_id
22 23 24 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 22 def location_flag @location_flag end |
#location_id ⇒ Object
References a station, a ship or an item_id if this blueprint is located within a container. If the return value is an item_id, then the Character AssetList API must be queried to find the container using the given item_id to determine the correct location of the Blueprint.
25 26 27 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 25 def location_id @location_id end |
#material_efficiency ⇒ Object
Material Efficiency Level of the blueprint.
28 29 30 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 28 def material_efficiency @material_efficiency end |
#quantity ⇒ Object
A range of numbers with a minimum of -2 and no maximum value where -1 is an original and -2 is a copy. It can be a positive integer if it is a stack of blueprint originals fresh from the market (e.g. no activities performed on them yet).
31 32 33 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 31 def quantity @quantity end |
#runs ⇒ Object
Number of runs remaining if the blueprint is a copy, -1 if it is an original.
34 35 36 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 34 def runs @runs end |
#time_efficiency ⇒ Object
Time Efficiency Level of the blueprint.
37 38 39 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 37 def time_efficiency @time_efficiency end |
#type_id ⇒ Object
Returns the value of attribute type_id.
39 40 41 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 39 def type_id @type_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 64 def self.attribute_map { :'item_id' => :'item_id', :'location_flag' => :'location_flag', :'location_id' => :'location_id', :'material_efficiency' => :'material_efficiency', :'quantity' => :'quantity', :'runs' => :'runs', :'time_efficiency' => :'time_efficiency', :'type_id' => :'type_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 339 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 88 def self.openapi_types { :'item_id' => :'Integer', :'location_flag' => :'String', :'location_id' => :'Integer', :'material_efficiency' => :'Integer', :'quantity' => :'Integer', :'runs' => :'Integer', :'time_efficiency' => :'Integer', :'type_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 311 def ==(o) return true if self.equal?(o) self.class == o.class && item_id == o.item_id && location_flag == o.location_flag && location_id == o.location_id && material_efficiency == o.material_efficiency && quantity == o.quantity && runs == o.runs && time_efficiency == o.time_efficiency && type_id == o.type_id end |
#eql?(o) ⇒ Boolean
326 327 328 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 326 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
332 333 334 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 332 def hash [item_id, location_flag, location_id, material_efficiency, quantity, runs, time_efficiency, type_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 174 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @item_id.nil? invalid_properties.push('invalid value for "item_id", item_id cannot be nil.') end if @location_flag.nil? invalid_properties.push('invalid value for "location_flag", location_flag cannot be nil.') end if @location_id.nil? invalid_properties.push('invalid value for "location_id", location_id cannot be nil.') end if @material_efficiency.nil? invalid_properties.push('invalid value for "material_efficiency", material_efficiency cannot be nil.') end if @quantity.nil? invalid_properties.push('invalid value for "quantity", quantity cannot be nil.') end if @runs.nil? invalid_properties.push('invalid value for "runs", runs cannot be nil.') end if @time_efficiency.nil? invalid_properties.push('invalid value for "time_efficiency", time_efficiency cannot be nil.') end if @type_id.nil? invalid_properties.push('invalid value for "type_id", type_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/ruby-esi/models/characters_character_id_blueprints_get_inner.rb', line 214 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @item_id.nil? return false if @location_flag.nil? location_flag_validator = EnumAttributeValidator.new('String', ["AutoFit", "Cargo", "CorpseBay", "DroneBay", "FleetHangar", "Deliveries", "HiddenModifiers", "Hangar", "HangarAll", "LoSlot0", "LoSlot1", "LoSlot2", "LoSlot3", "LoSlot4", "LoSlot5", "LoSlot6", "LoSlot7", "MedSlot0", "MedSlot1", "MedSlot2", "MedSlot3", "MedSlot4", "MedSlot5", "MedSlot6", "MedSlot7", "HiSlot0", "HiSlot1", "HiSlot2", "HiSlot3", "HiSlot4", "HiSlot5", "HiSlot6", "HiSlot7", "AssetSafety", "Locked", "Unlocked", "Implant", "QuafeBay", "RigSlot0", "RigSlot1", "RigSlot2", "RigSlot3", "RigSlot4", "RigSlot5", "RigSlot6", "RigSlot7", "ShipHangar", "SpecializedFuelBay", "SpecializedOreHold", "SpecializedGasHold", "SpecializedMineralHold", "SpecializedSalvageHold", "SpecializedShipHold", "SpecializedSmallShipHold", "SpecializedMediumShipHold", "SpecializedLargeShipHold", "SpecializedIndustrialShipHold", "SpecializedAmmoHold", "SpecializedCommandCenterHold", "SpecializedPlanetaryCommoditiesHold", "SpecializedMaterialBay", "SubSystemSlot0", "SubSystemSlot1", "SubSystemSlot2", "SubSystemSlot3", "SubSystemSlot4", "SubSystemSlot5", "SubSystemSlot6", "SubSystemSlot7", "FighterBay", "FighterTube0", "FighterTube1", "FighterTube2", "FighterTube3", "FighterTube4", "Module"]) return false unless location_flag_validator.valid?(@location_flag) return false if @location_id.nil? return false if @material_efficiency.nil? return false if @quantity.nil? return false if @runs.nil? return false if @time_efficiency.nil? return false if @type_id.nil? true end |