Class: ESI::CharactersCharacterIdCalendarEventIdGet
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdCalendarEventIdGet
- Defined in:
- lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb
Overview
Full details of a specific event
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#date ⇒ Object
Returns the value of attribute date.
-
#duration ⇒ Object
Length in minutes.
-
#event_id ⇒ Object
Returns the value of attribute event_id.
-
#importance ⇒ Object
Returns the value of attribute importance.
-
#owner_id ⇒ Object
Returns the value of attribute owner_id.
-
#owner_name ⇒ Object
Returns the value of attribute owner_name.
-
#owner_type ⇒ Object
Returns the value of attribute owner_type.
-
#response ⇒ Object
Returns the value of attribute response.
-
#text ⇒ Object
Returns the value of attribute text.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdCalendarEventIdGet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdCalendarEventIdGet
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdCalendarEventIdGet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdCalendarEventIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date') self.date = attributes[:'date'] else self.date = nil end if attributes.key?(:'duration') self.duration = attributes[:'duration'] else self.duration = nil end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] else self.event_id = nil end if attributes.key?(:'importance') self.importance = attributes[:'importance'] else self.importance = nil end if attributes.key?(:'owner_id') self.owner_id = attributes[:'owner_id'] else self.owner_id = nil end if attributes.key?(:'owner_name') self.owner_name = attributes[:'owner_name'] else self.owner_name = nil end if attributes.key?(:'owner_type') self.owner_type = attributes[:'owner_type'] else self.owner_type = nil end if attributes.key?(:'response') self.response = attributes[:'response'] else self.response = nil end if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end end |
Instance Attribute Details
#date ⇒ Object
Returns the value of attribute date.
19 20 21 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 19 def date @date end |
#duration ⇒ Object
Length in minutes
22 23 24 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 22 def duration @duration end |
#event_id ⇒ Object
Returns the value of attribute event_id.
24 25 26 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 24 def event_id @event_id end |
#importance ⇒ Object
Returns the value of attribute importance.
26 27 28 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 26 def importance @importance end |
#owner_id ⇒ Object
Returns the value of attribute owner_id.
28 29 30 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 28 def owner_id @owner_id end |
#owner_name ⇒ Object
Returns the value of attribute owner_name.
30 31 32 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 30 def owner_name @owner_name end |
#owner_type ⇒ Object
Returns the value of attribute owner_type.
32 33 34 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 32 def owner_type @owner_type end |
#response ⇒ Object
Returns the value of attribute response.
34 35 36 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 34 def response @response end |
#text ⇒ Object
Returns the value of attribute text.
36 37 38 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 36 def text @text end |
#title ⇒ Object
Returns the value of attribute title.
38 39 40 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 38 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 63 def self.attribute_map { :'date' => :'date', :'duration' => :'duration', :'event_id' => :'event_id', :'importance' => :'importance', :'owner_id' => :'owner_id', :'owner_name' => :'owner_name', :'owner_type' => :'owner_type', :'response' => :'response', :'text' => :'text', :'title' => :'title' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 386 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 89 def self.openapi_types { :'date' => :'Time', :'duration' => :'Integer', :'event_id' => :'Integer', :'importance' => :'Integer', :'owner_id' => :'Integer', :'owner_name' => :'String', :'owner_type' => :'String', :'response' => :'String', :'text' => :'String', :'title' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 356 def ==(o) return true if self.equal?(o) self.class == o.class && date == o.date && duration == o.duration && event_id == o.event_id && importance == o.importance && owner_id == o.owner_id && owner_name == o.owner_name && owner_type == o.owner_type && response == o.response && text == o.text && title == o.title end |
#eql?(o) ⇒ Boolean
373 374 375 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 373 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
379 380 381 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 379 def hash [date, duration, event_id, importance, owner_id, owner_name, owner_type, response, text, title].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 189 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @date.nil? invalid_properties.push('invalid value for "date", date cannot be nil.') end if @duration.nil? invalid_properties.push('invalid value for "duration", duration cannot be nil.') end if @event_id.nil? invalid_properties.push('invalid value for "event_id", event_id cannot be nil.') end if @importance.nil? invalid_properties.push('invalid value for "importance", importance cannot be nil.') end if @owner_id.nil? invalid_properties.push('invalid value for "owner_id", owner_id cannot be nil.') end if @owner_name.nil? invalid_properties.push('invalid value for "owner_name", owner_name cannot be nil.') end if @owner_type.nil? invalid_properties.push('invalid value for "owner_type", owner_type cannot be nil.') end if @response.nil? invalid_properties.push('invalid value for "response", response cannot be nil.') end if @text.nil? invalid_properties.push('invalid value for "text", text cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 408 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/ruby-esi/models/characters_character_id_calendar_event_id_get.rb', line 237 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @date.nil? return false if @duration.nil? return false if @event_id.nil? return false if @importance.nil? return false if @owner_id.nil? return false if @owner_name.nil? return false if @owner_type.nil? owner_type_validator = EnumAttributeValidator.new('String', ["eve_server", "corporation", "faction", "character", "alliance"]) return false unless owner_type_validator.valid?(@owner_type) return false if @response.nil? return false if @text.nil? return false if @title.nil? true end |