Class: ESI::CharactersCharacterIdContactsGetInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdContactsGetInner
- Defined in:
- lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#contact_id ⇒ Object
Returns the value of attribute contact_id.
-
#contact_type ⇒ Object
Returns the value of attribute contact_type.
-
#is_blocked ⇒ Object
Whether this contact is in the blocked list.
-
#is_watched ⇒ Object
Whether this contact is being watched.
-
#label_ids ⇒ Object
Returns the value of attribute label_ids.
-
#standing ⇒ Object
Standing of the contact.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdContactsGetInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdContactsGetInner
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdContactsGetInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdContactsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'contact_id') self.contact_id = attributes[:'contact_id'] else self.contact_id = nil end if attributes.key?(:'contact_type') self.contact_type = attributes[:'contact_type'] else self.contact_type = nil end if attributes.key?(:'is_blocked') self.is_blocked = attributes[:'is_blocked'] end if attributes.key?(:'is_watched') self.is_watched = attributes[:'is_watched'] end if attributes.key?(:'label_ids') if (value = attributes[:'label_ids']).is_a?(Array) self.label_ids = value end end if attributes.key?(:'standing') self.standing = attributes[:'standing'] else self.standing = nil end end |
Instance Attribute Details
#contact_id ⇒ Object
Returns the value of attribute contact_id.
18 19 20 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 18 def contact_id @contact_id end |
#contact_type ⇒ Object
Returns the value of attribute contact_type.
20 21 22 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 20 def contact_type @contact_type end |
#is_blocked ⇒ Object
Whether this contact is in the blocked list. Note a missing value denotes unknown, not true or false
23 24 25 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 23 def is_blocked @is_blocked end |
#is_watched ⇒ Object
Whether this contact is being watched
26 27 28 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 26 def is_watched @is_watched end |
#label_ids ⇒ Object
Returns the value of attribute label_ids.
28 29 30 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 28 def label_ids @label_ids end |
#standing ⇒ Object
Standing of the contact
31 32 33 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 31 def standing @standing end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 56 def self.attribute_map { :'contact_id' => :'contact_id', :'contact_type' => :'contact_type', :'is_blocked' => :'is_blocked', :'is_watched' => :'is_watched', :'label_ids' => :'label_ids', :'standing' => :'standing' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 234 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 78 def self.openapi_types { :'contact_id' => :'Integer', :'contact_type' => :'String', :'is_blocked' => :'Boolean', :'is_watched' => :'Boolean', :'label_ids' => :'Array<Integer>', :'standing' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && contact_id == o.contact_id && contact_type == o.contact_type && is_blocked == o.is_blocked && is_watched == o.is_watched && label_ids == o.label_ids && standing == o.standing end |
#eql?(o) ⇒ Boolean
221 222 223 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 221 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 227 def hash [contact_id, contact_type, is_blocked, is_watched, label_ids, standing].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @contact_id.nil? invalid_properties.push('invalid value for "contact_id", contact_id cannot be nil.') end if @contact_type.nil? invalid_properties.push('invalid value for "contact_type", contact_type cannot be nil.') end if @standing.nil? invalid_properties.push('invalid value for "standing", standing cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 |
# File 'lib/ruby-esi/models/characters_character_id_contacts_get_inner.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @contact_id.nil? return false if @contact_type.nil? contact_type_validator = EnumAttributeValidator.new('String', ["character", "corporation", "alliance", "faction"]) return false unless contact_type_validator.valid?(@contact_type) return false if @standing.nil? true end |