Class: ESI::CharactersCharacterIdContractsGetInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdContractsGetInner
- Defined in:
- lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#acceptor_id ⇒ Object
Who will accept the contract.
-
#assignee_id ⇒ Object
ID to whom the contract is assigned, can be alliance, corporation or character ID.
-
#availability ⇒ Object
To whom the contract is available.
-
#buyout ⇒ Object
Buyout price (for Auctions only).
-
#collateral ⇒ Object
Collateral price (for Couriers only).
-
#contract_id ⇒ Object
Returns the value of attribute contract_id.
-
#date_accepted ⇒ Object
Date of confirmation of contract.
-
#date_completed ⇒ Object
Date of completed of contract.
-
#date_expired ⇒ Object
Expiration date of the contract.
-
#date_issued ⇒ Object
Сreation date of the contract.
-
#days_to_complete ⇒ Object
Number of days to perform the contract.
-
#end_location_id ⇒ Object
End location ID (for Couriers contract).
-
#for_corporation ⇒ Object
true if the contract was issued on behalf of the issuer’s corporation.
-
#issuer_corporation_id ⇒ Object
Character’s corporation ID for the issuer.
-
#issuer_id ⇒ Object
Character ID for the issuer.
-
#price ⇒ Object
Price of contract (for ItemsExchange and Auctions).
-
#reward ⇒ Object
Remuneration for contract (for Couriers only).
-
#start_location_id ⇒ Object
Start location ID (for Couriers contract).
-
#status ⇒ Object
Status of the the contract.
-
#title ⇒ Object
Title of the contract.
-
#type ⇒ Object
Type of the contract.
-
#volume ⇒ Object
Volume of items in the contract.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdContractsGetInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdContractsGetInner
Initializes the object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 179 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdContractsGetInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdContractsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acceptor_id') self.acceptor_id = attributes[:'acceptor_id'] else self.acceptor_id = nil end if attributes.key?(:'assignee_id') self.assignee_id = attributes[:'assignee_id'] else self.assignee_id = nil end if attributes.key?(:'availability') self.availability = attributes[:'availability'] else self.availability = nil end if attributes.key?(:'buyout') self.buyout = attributes[:'buyout'] end if attributes.key?(:'collateral') self.collateral = attributes[:'collateral'] end if attributes.key?(:'contract_id') self.contract_id = attributes[:'contract_id'] else self.contract_id = nil end if attributes.key?(:'date_accepted') self.date_accepted = attributes[:'date_accepted'] end if attributes.key?(:'date_completed') self.date_completed = attributes[:'date_completed'] end if attributes.key?(:'date_expired') self.date_expired = attributes[:'date_expired'] else self.date_expired = nil end if attributes.key?(:'date_issued') self.date_issued = attributes[:'date_issued'] else self.date_issued = nil end if attributes.key?(:'days_to_complete') self.days_to_complete = attributes[:'days_to_complete'] end if attributes.key?(:'end_location_id') self.end_location_id = attributes[:'end_location_id'] end if attributes.key?(:'for_corporation') self.for_corporation = attributes[:'for_corporation'] else self.for_corporation = nil end if attributes.key?(:'issuer_corporation_id') self.issuer_corporation_id = attributes[:'issuer_corporation_id'] else self.issuer_corporation_id = nil end if attributes.key?(:'issuer_id') self.issuer_id = attributes[:'issuer_id'] else self.issuer_id = nil end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'reward') self.reward = attributes[:'reward'] end if attributes.key?(:'start_location_id') self.start_location_id = attributes[:'start_location_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'volume') self.volume = attributes[:'volume'] end end |
Instance Attribute Details
#acceptor_id ⇒ Object
Who will accept the contract
19 20 21 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 19 def acceptor_id @acceptor_id end |
#assignee_id ⇒ Object
ID to whom the contract is assigned, can be alliance, corporation or character ID
22 23 24 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 22 def assignee_id @assignee_id end |
#availability ⇒ Object
To whom the contract is available
25 26 27 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 25 def availability @availability end |
#buyout ⇒ Object
Buyout price (for Auctions only)
28 29 30 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 28 def buyout @buyout end |
#collateral ⇒ Object
Collateral price (for Couriers only)
31 32 33 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 31 def collateral @collateral end |
#contract_id ⇒ Object
Returns the value of attribute contract_id.
33 34 35 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 33 def contract_id @contract_id end |
#date_accepted ⇒ Object
Date of confirmation of contract
36 37 38 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 36 def date_accepted @date_accepted end |
#date_completed ⇒ Object
Date of completed of contract
39 40 41 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 39 def date_completed @date_completed end |
#date_expired ⇒ Object
Expiration date of the contract
42 43 44 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 42 def date_expired @date_expired end |
#date_issued ⇒ Object
Сreation date of the contract
45 46 47 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 45 def date_issued @date_issued end |
#days_to_complete ⇒ Object
Number of days to perform the contract
48 49 50 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 48 def days_to_complete @days_to_complete end |
#end_location_id ⇒ Object
End location ID (for Couriers contract)
51 52 53 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 51 def end_location_id @end_location_id end |
#for_corporation ⇒ Object
true if the contract was issued on behalf of the issuer’s corporation
54 55 56 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 54 def for_corporation @for_corporation end |
#issuer_corporation_id ⇒ Object
Character’s corporation ID for the issuer
57 58 59 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 57 def issuer_corporation_id @issuer_corporation_id end |
#issuer_id ⇒ Object
Character ID for the issuer
60 61 62 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 60 def issuer_id @issuer_id end |
#price ⇒ Object
Price of contract (for ItemsExchange and Auctions)
63 64 65 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 63 def price @price end |
#reward ⇒ Object
Remuneration for contract (for Couriers only)
66 67 68 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 66 def reward @reward end |
#start_location_id ⇒ Object
Start location ID (for Couriers contract)
69 70 71 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 69 def start_location_id @start_location_id end |
#status ⇒ Object
Status of the the contract
72 73 74 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 72 def status @status end |
#title ⇒ Object
Title of the contract
75 76 77 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 75 def title @title end |
#type ⇒ Object
Type of the contract
78 79 80 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 78 def type @type end |
#volume ⇒ Object
Volume of items in the contract
81 82 83 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 81 def volume @volume end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
134 135 136 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 134 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
139 140 141 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 139 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 106 def self.attribute_map { :'acceptor_id' => :'acceptor_id', :'assignee_id' => :'assignee_id', :'availability' => :'availability', :'buyout' => :'buyout', :'collateral' => :'collateral', :'contract_id' => :'contract_id', :'date_accepted' => :'date_accepted', :'date_completed' => :'date_completed', :'date_expired' => :'date_expired', :'date_issued' => :'date_issued', :'days_to_complete' => :'days_to_complete', :'end_location_id' => :'end_location_id', :'for_corporation' => :'for_corporation', :'issuer_corporation_id' => :'issuer_corporation_id', :'issuer_id' => :'issuer_id', :'price' => :'price', :'reward' => :'reward', :'start_location_id' => :'start_location_id', :'status' => :'status', :'title' => :'title', :'type' => :'type', :'volume' => :'volume' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 534 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
172 173 174 175 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 172 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 144 def self.openapi_types { :'acceptor_id' => :'Integer', :'assignee_id' => :'Integer', :'availability' => :'String', :'buyout' => :'Float', :'collateral' => :'Float', :'contract_id' => :'Integer', :'date_accepted' => :'Time', :'date_completed' => :'Time', :'date_expired' => :'Time', :'date_issued' => :'Time', :'days_to_complete' => :'Integer', :'end_location_id' => :'Integer', :'for_corporation' => :'Boolean', :'issuer_corporation_id' => :'Integer', :'issuer_id' => :'Integer', :'price' => :'Float', :'reward' => :'Float', :'start_location_id' => :'Integer', :'status' => :'String', :'title' => :'String', :'type' => :'String', :'volume' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 492 def ==(o) return true if self.equal?(o) self.class == o.class && acceptor_id == o.acceptor_id && assignee_id == o.assignee_id && availability == o.availability && buyout == o.buyout && collateral == o.collateral && contract_id == o.contract_id && date_accepted == o.date_accepted && date_completed == o.date_completed && date_expired == o.date_expired && date_issued == o.date_issued && days_to_complete == o.days_to_complete && end_location_id == o.end_location_id && for_corporation == o.for_corporation && issuer_corporation_id == o.issuer_corporation_id && issuer_id == o.issuer_id && price == o.price && reward == o.reward && start_location_id == o.start_location_id && status == o.status && title == o.title && type == o.type && volume == o.volume end |
#eql?(o) ⇒ Boolean
521 522 523 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 521 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
527 528 529 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 527 def hash [acceptor_id, assignee_id, availability, buyout, collateral, contract_id, date_accepted, date_completed, date_expired, date_issued, days_to_complete, end_location_id, for_corporation, issuer_corporation_id, issuer_id, price, reward, start_location_id, status, title, type, volume].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 306 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @acceptor_id.nil? invalid_properties.push('invalid value for "acceptor_id", acceptor_id cannot be nil.') end if @assignee_id.nil? invalid_properties.push('invalid value for "assignee_id", assignee_id cannot be nil.') end if @availability.nil? invalid_properties.push('invalid value for "availability", availability cannot be nil.') end if @contract_id.nil? invalid_properties.push('invalid value for "contract_id", contract_id cannot be nil.') end if @date_expired.nil? invalid_properties.push('invalid value for "date_expired", date_expired cannot be nil.') end if @date_issued.nil? invalid_properties.push('invalid value for "date_issued", date_issued cannot be nil.') end if @for_corporation.nil? invalid_properties.push('invalid value for "for_corporation", for_corporation cannot be nil.') end if @issuer_corporation_id.nil? invalid_properties.push('invalid value for "issuer_corporation_id", issuer_corporation_id cannot be nil.') end if @issuer_id.nil? invalid_properties.push('invalid value for "issuer_id", issuer_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 556 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/ruby-esi/models/characters_character_id_contracts_get_inner.rb', line 358 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @acceptor_id.nil? return false if @assignee_id.nil? return false if @availability.nil? availability_validator = EnumAttributeValidator.new('String', ["public", "personal", "corporation", "alliance"]) return false unless availability_validator.valid?(@availability) return false if @contract_id.nil? return false if @date_expired.nil? return false if @date_issued.nil? return false if @for_corporation.nil? return false if @issuer_corporation_id.nil? return false if @issuer_id.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["outstanding", "in_progress", "finished_issuer", "finished_contractor", "finished", "cancelled", "rejected", "failed", "deleted", "reversed"]) return false unless status_validator.valid?(@status) return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["unknown", "item_exchange", "auction", "courier", "loan"]) return false unless type_validator.valid?(@type) true end |