Class: ESI::CharactersCharacterIdMailMailIdGet
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdMailMailIdGet
- Defined in:
- lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb
Instance Attribute Summary collapse
-
#body ⇒ Object
Mail’s body.
-
#from ⇒ Object
From whom the mail was sent.
-
#labels ⇒ Object
Labels attached to the mail.
-
#read ⇒ Object
Whether the mail is flagged as read.
-
#recipients ⇒ Object
Recipients of the mail.
-
#subject ⇒ Object
Mail subject.
-
#timestamp ⇒ Object
When the mail was sent.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdMailMailIdGet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdMailMailIdGet
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdMailMailIdGet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdMailMailIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'labels') if (value = attributes[:'labels']).is_a?(Array) self.labels = value end end if attributes.key?(:'read') self.read = attributes[:'read'] end if attributes.key?(:'recipients') if (value = attributes[:'recipients']).is_a?(Array) self.recipients = value end end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end end |
Instance Attribute Details
#body ⇒ Object
Mail’s body
19 20 21 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 19 def body @body end |
#from ⇒ Object
From whom the mail was sent
22 23 24 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 22 def from @from end |
#labels ⇒ Object
Labels attached to the mail
25 26 27 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 25 def labels @labels end |
#read ⇒ Object
Whether the mail is flagged as read
28 29 30 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 28 def read @read end |
#recipients ⇒ Object
Recipients of the mail
31 32 33 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 31 def recipients @recipients end |
#subject ⇒ Object
Mail subject
34 35 36 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 34 def subject @subject end |
#timestamp ⇒ Object
When the mail was sent
37 38 39 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 37 def end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 40 def self.attribute_map { :'body' => :'body', :'from' => :'from', :'labels' => :'labels', :'read' => :'read', :'recipients' => :'recipients', :'subject' => :'subject', :'timestamp' => :'timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 63 def self.openapi_types { :'body' => :'String', :'from' => :'Integer', :'labels' => :'Array<Integer>', :'read' => :'Boolean', :'recipients' => :'Array<PostCharactersCharacterIdMailRequestRecipientsInner>', :'subject' => :'String', :'timestamp' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && body == o.body && from == o.from && labels == o.labels && read == o.read && recipients == o.recipients && subject == o.subject && == o. end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 187 def hash [body, from, labels, read, recipients, subject, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 |
# File 'lib/ruby-esi/models/characters_character_id_mail_mail_id_get.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |