Class: ESI::CharactersCharacterIdSearchGet
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersCharacterIdSearchGet
- Defined in:
- lib/ruby-esi/models/characters_character_id_search_get.rb
Instance Attribute Summary collapse
-
#agent ⇒ Object
Returns the value of attribute agent.
-
#alliance ⇒ Object
Returns the value of attribute alliance.
-
#character ⇒ Object
Returns the value of attribute character.
-
#constellation ⇒ Object
Returns the value of attribute constellation.
-
#corporation ⇒ Object
Returns the value of attribute corporation.
-
#faction ⇒ Object
Returns the value of attribute faction.
-
#inventory_type ⇒ Object
Returns the value of attribute inventory_type.
-
#region ⇒ Object
Returns the value of attribute region.
-
#solar_system ⇒ Object
Returns the value of attribute solar_system.
-
#station ⇒ Object
Returns the value of attribute station.
-
#structure ⇒ Object
Returns the value of attribute structure.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersCharacterIdSearchGet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersCharacterIdSearchGet
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersCharacterIdSearchGet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersCharacterIdSearchGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agent') if (value = attributes[:'agent']).is_a?(Array) self.agent = value end end if attributes.key?(:'alliance') if (value = attributes[:'alliance']).is_a?(Array) self.alliance = value end end if attributes.key?(:'character') if (value = attributes[:'character']).is_a?(Array) self.character = value end end if attributes.key?(:'constellation') if (value = attributes[:'constellation']).is_a?(Array) self.constellation = value end end if attributes.key?(:'corporation') if (value = attributes[:'corporation']).is_a?(Array) self.corporation = value end end if attributes.key?(:'faction') if (value = attributes[:'faction']).is_a?(Array) self.faction = value end end if attributes.key?(:'inventory_type') if (value = attributes[:'inventory_type']).is_a?(Array) self.inventory_type = value end end if attributes.key?(:'region') if (value = attributes[:'region']).is_a?(Array) self.region = value end end if attributes.key?(:'solar_system') if (value = attributes[:'solar_system']).is_a?(Array) self.solar_system = value end end if attributes.key?(:'station') if (value = attributes[:'station']).is_a?(Array) self.station = value end end if attributes.key?(:'structure') if (value = attributes[:'structure']).is_a?(Array) self.structure = value end end end |
Instance Attribute Details
#agent ⇒ Object
Returns the value of attribute agent.
18 19 20 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 18 def agent @agent end |
#alliance ⇒ Object
Returns the value of attribute alliance.
20 21 22 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 20 def alliance @alliance end |
#character ⇒ Object
Returns the value of attribute character.
22 23 24 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 22 def character @character end |
#constellation ⇒ Object
Returns the value of attribute constellation.
24 25 26 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 24 def constellation @constellation end |
#corporation ⇒ Object
Returns the value of attribute corporation.
26 27 28 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 26 def corporation @corporation end |
#faction ⇒ Object
Returns the value of attribute faction.
28 29 30 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 28 def faction @faction end |
#inventory_type ⇒ Object
Returns the value of attribute inventory_type.
30 31 32 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 30 def inventory_type @inventory_type end |
#region ⇒ Object
Returns the value of attribute region.
32 33 34 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 32 def region @region end |
#solar_system ⇒ Object
Returns the value of attribute solar_system.
34 35 36 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 34 def solar_system @solar_system end |
#station ⇒ Object
Returns the value of attribute station.
36 37 38 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 36 def station @station end |
#structure ⇒ Object
Returns the value of attribute structure.
38 39 40 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 38 def structure @structure end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 41 def self.attribute_map { :'agent' => :'agent', :'alliance' => :'alliance', :'character' => :'character', :'constellation' => :'constellation', :'corporation' => :'corporation', :'faction' => :'faction', :'inventory_type' => :'inventory_type', :'region' => :'region', :'solar_system' => :'solar_system', :'station' => :'station', :'structure' => :'structure' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 221 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 68 def self.openapi_types { :'agent' => :'Array<Integer>', :'alliance' => :'Array<Integer>', :'character' => :'Array<Integer>', :'constellation' => :'Array<Integer>', :'corporation' => :'Array<Integer>', :'faction' => :'Array<Integer>', :'inventory_type' => :'Array<Integer>', :'region' => :'Array<Integer>', :'solar_system' => :'Array<Integer>', :'station' => :'Array<Integer>', :'structure' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && agent == o.agent && alliance == o.alliance && character == o.character && constellation == o.constellation && corporation == o.corporation && faction == o.faction && inventory_type == o.inventory_type && region == o.region && solar_system == o.solar_system && station == o.station && structure == o.structure end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 214 def hash [agent, alliance, character, constellation, corporation, faction, inventory_type, region, solar_system, station, structure].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 243 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 |
# File 'lib/ruby-esi/models/characters_character_id_search_get.rb', line 183 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |