Class: ESI::CharactersSkillqueueSkill
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::CharactersSkillqueueSkill
- Defined in:
- lib/ruby-esi/models/characters_skillqueue_skill.rb
Instance Attribute Summary collapse
-
#finish_date ⇒ Object
The date the skill training will finish.
-
#finished_level ⇒ Object
The level the skill is training for.
-
#level_end_sp ⇒ Object
The Skill Points at the end of the level.
-
#level_start_sp ⇒ Object
The Skill Points at the start of the level.
-
#queue_position ⇒ Object
The position of the skill in the queue.
-
#skill_id ⇒ Object
The TypeID of the skill.
-
#start_date ⇒ Object
The date the skill training will start/continue.
-
#training_start_sp ⇒ Object
The Skill Points at the start of training.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CharactersSkillqueueSkill
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CharactersSkillqueueSkill
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::CharactersSkillqueueSkill` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::CharactersSkillqueueSkill`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'finish_date') self.finish_date = attributes[:'finish_date'] end if attributes.key?(:'finished_level') self.finished_level = attributes[:'finished_level'] else self.finished_level = nil end if attributes.key?(:'level_end_sp') self.level_end_sp = attributes[:'level_end_sp'] end if attributes.key?(:'level_start_sp') self.level_start_sp = attributes[:'level_start_sp'] end if attributes.key?(:'queue_position') self.queue_position = attributes[:'queue_position'] else self.queue_position = nil end if attributes.key?(:'skill_id') self.skill_id = attributes[:'skill_id'] else self.skill_id = nil end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'training_start_sp') self.training_start_sp = attributes[:'training_start_sp'] end end |
Instance Attribute Details
#finish_date ⇒ Object
The date the skill training will finish
19 20 21 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 19 def finish_date @finish_date end |
#finished_level ⇒ Object
The level the skill is training for
22 23 24 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 22 def finished_level @finished_level end |
#level_end_sp ⇒ Object
The Skill Points at the end of the level
25 26 27 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 25 def level_end_sp @level_end_sp end |
#level_start_sp ⇒ Object
The Skill Points at the start of the level
28 29 30 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 28 def level_start_sp @level_start_sp end |
#queue_position ⇒ Object
The position of the skill in the queue
31 32 33 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 31 def queue_position @queue_position end |
#skill_id ⇒ Object
The TypeID of the skill
34 35 36 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 34 def skill_id @skill_id end |
#start_date ⇒ Object
The date the skill training will start/continue
37 38 39 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 37 def start_date @start_date end |
#training_start_sp ⇒ Object
The Skill Points at the start of training
40 41 42 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 40 def training_start_sp @training_start_sp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 43 def self.attribute_map { :'finish_date' => :'finish_date', :'finished_level' => :'finished_level', :'level_end_sp' => :'level_end_sp', :'level_start_sp' => :'level_start_sp', :'queue_position' => :'queue_position', :'skill_id' => :'skill_id', :'start_date' => :'start_date', :'training_start_sp' => :'training_start_sp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 67 def self.openapi_types { :'finish_date' => :'Time', :'finished_level' => :'Integer', :'level_end_sp' => :'Integer', :'level_start_sp' => :'Integer', :'queue_position' => :'Integer', :'skill_id' => :'Integer', :'start_date' => :'Time', :'training_start_sp' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && finish_date == o.finish_date && finished_level == o.finished_level && level_end_sp == o.level_end_sp && level_start_sp == o.level_start_sp && queue_position == o.queue_position && skill_id == o.skill_id && start_date == o.start_date && training_start_sp == o.training_start_sp end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 224 def hash [finish_date, finished_level, level_end_sp, level_start_sp, queue_position, skill_id, start_date, training_start_sp].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @finished_level.nil? invalid_properties.push('invalid value for "finished_level", finished_level cannot be nil.') end if @queue_position.nil? invalid_properties.push('invalid value for "queue_position", queue_position cannot be nil.') end if @skill_id.nil? invalid_properties.push('invalid value for "skill_id", skill_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 253 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 |
# File 'lib/ruby-esi/models/characters_skillqueue_skill.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @finished_level.nil? return false if @queue_position.nil? return false if @skill_id.nil? true end |