Class: ESI::DogmaEffectsEffectIdGet
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::DogmaEffectsEffectIdGet
- Defined in:
- lib/ruby-esi/models/dogma_effects_effect_id_get.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#disallow_auto_repeat ⇒ Object
Returns the value of attribute disallow_auto_repeat.
-
#discharge_attribute_id ⇒ Object
Returns the value of attribute discharge_attribute_id.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#duration_attribute_id ⇒ Object
Returns the value of attribute duration_attribute_id.
-
#effect_category ⇒ Object
Returns the value of attribute effect_category.
-
#effect_id ⇒ Object
Returns the value of attribute effect_id.
-
#electronic_chance ⇒ Object
Returns the value of attribute electronic_chance.
-
#falloff_attribute_id ⇒ Object
Returns the value of attribute falloff_attribute_id.
-
#icon_id ⇒ Object
Returns the value of attribute icon_id.
-
#is_assistance ⇒ Object
Returns the value of attribute is_assistance.
-
#is_offensive ⇒ Object
Returns the value of attribute is_offensive.
-
#is_warp_safe ⇒ Object
Returns the value of attribute is_warp_safe.
-
#modifiers ⇒ Object
Returns the value of attribute modifiers.
-
#name ⇒ Object
Returns the value of attribute name.
-
#post_expression ⇒ Object
Returns the value of attribute post_expression.
-
#pre_expression ⇒ Object
Returns the value of attribute pre_expression.
-
#published ⇒ Object
Returns the value of attribute published.
-
#range_attribute_id ⇒ Object
Returns the value of attribute range_attribute_id.
-
#range_chance ⇒ Object
Returns the value of attribute range_chance.
-
#tracking_speed_attribute_id ⇒ Object
Returns the value of attribute tracking_speed_attribute_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DogmaEffectsEffectIdGet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DogmaEffectsEffectIdGet
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::DogmaEffectsEffectIdGet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::DogmaEffectsEffectIdGet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'disallow_auto_repeat') self.disallow_auto_repeat = attributes[:'disallow_auto_repeat'] end if attributes.key?(:'discharge_attribute_id') self.discharge_attribute_id = attributes[:'discharge_attribute_id'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'duration_attribute_id') self.duration_attribute_id = attributes[:'duration_attribute_id'] end if attributes.key?(:'effect_category') self.effect_category = attributes[:'effect_category'] end if attributes.key?(:'effect_id') self.effect_id = attributes[:'effect_id'] else self.effect_id = nil end if attributes.key?(:'electronic_chance') self.electronic_chance = attributes[:'electronic_chance'] end if attributes.key?(:'falloff_attribute_id') self.falloff_attribute_id = attributes[:'falloff_attribute_id'] end if attributes.key?(:'icon_id') self.icon_id = attributes[:'icon_id'] end if attributes.key?(:'is_assistance') self.is_assistance = attributes[:'is_assistance'] end if attributes.key?(:'is_offensive') self.is_offensive = attributes[:'is_offensive'] end if attributes.key?(:'is_warp_safe') self.is_warp_safe = attributes[:'is_warp_safe'] end if attributes.key?(:'modifiers') if (value = attributes[:'modifiers']).is_a?(Array) self.modifiers = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'post_expression') self.post_expression = attributes[:'post_expression'] end if attributes.key?(:'pre_expression') self.pre_expression = attributes[:'pre_expression'] end if attributes.key?(:'published') self.published = attributes[:'published'] end if attributes.key?(:'range_attribute_id') self.range_attribute_id = attributes[:'range_attribute_id'] end if attributes.key?(:'range_chance') self.range_chance = attributes[:'range_chance'] end if attributes.key?(:'tracking_speed_attribute_id') self.tracking_speed_attribute_id = attributes[:'tracking_speed_attribute_id'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
18 19 20 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 18 def description @description end |
#disallow_auto_repeat ⇒ Object
Returns the value of attribute disallow_auto_repeat.
20 21 22 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 20 def disallow_auto_repeat @disallow_auto_repeat end |
#discharge_attribute_id ⇒ Object
Returns the value of attribute discharge_attribute_id.
22 23 24 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 22 def discharge_attribute_id @discharge_attribute_id end |
#display_name ⇒ Object
Returns the value of attribute display_name.
24 25 26 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 24 def display_name @display_name end |
#duration_attribute_id ⇒ Object
Returns the value of attribute duration_attribute_id.
26 27 28 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 26 def duration_attribute_id @duration_attribute_id end |
#effect_category ⇒ Object
Returns the value of attribute effect_category.
28 29 30 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 28 def effect_category @effect_category end |
#effect_id ⇒ Object
Returns the value of attribute effect_id.
30 31 32 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 30 def effect_id @effect_id end |
#electronic_chance ⇒ Object
Returns the value of attribute electronic_chance.
32 33 34 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 32 def electronic_chance @electronic_chance end |
#falloff_attribute_id ⇒ Object
Returns the value of attribute falloff_attribute_id.
34 35 36 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 34 def falloff_attribute_id @falloff_attribute_id end |
#icon_id ⇒ Object
Returns the value of attribute icon_id.
36 37 38 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 36 def icon_id @icon_id end |
#is_assistance ⇒ Object
Returns the value of attribute is_assistance.
38 39 40 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 38 def is_assistance @is_assistance end |
#is_offensive ⇒ Object
Returns the value of attribute is_offensive.
40 41 42 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 40 def is_offensive @is_offensive end |
#is_warp_safe ⇒ Object
Returns the value of attribute is_warp_safe.
42 43 44 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 42 def is_warp_safe @is_warp_safe end |
#modifiers ⇒ Object
Returns the value of attribute modifiers.
44 45 46 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 44 def modifiers @modifiers end |
#name ⇒ Object
Returns the value of attribute name.
46 47 48 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 46 def name @name end |
#post_expression ⇒ Object
Returns the value of attribute post_expression.
48 49 50 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 48 def post_expression @post_expression end |
#pre_expression ⇒ Object
Returns the value of attribute pre_expression.
50 51 52 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 50 def pre_expression @pre_expression end |
#published ⇒ Object
Returns the value of attribute published.
52 53 54 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 52 def published @published end |
#range_attribute_id ⇒ Object
Returns the value of attribute range_attribute_id.
54 55 56 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 54 def range_attribute_id @range_attribute_id end |
#range_chance ⇒ Object
Returns the value of attribute range_chance.
56 57 58 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 56 def range_chance @range_chance end |
#tracking_speed_attribute_id ⇒ Object
Returns the value of attribute tracking_speed_attribute_id.
58 59 60 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 58 def tracking_speed_attribute_id @tracking_speed_attribute_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 61 def self.attribute_map { :'description' => :'description', :'disallow_auto_repeat' => :'disallow_auto_repeat', :'discharge_attribute_id' => :'discharge_attribute_id', :'display_name' => :'display_name', :'duration_attribute_id' => :'duration_attribute_id', :'effect_category' => :'effect_category', :'effect_id' => :'effect_id', :'electronic_chance' => :'electronic_chance', :'falloff_attribute_id' => :'falloff_attribute_id', :'icon_id' => :'icon_id', :'is_assistance' => :'is_assistance', :'is_offensive' => :'is_offensive', :'is_warp_safe' => :'is_warp_safe', :'modifiers' => :'modifiers', :'name' => :'name', :'post_expression' => :'post_expression', :'pre_expression' => :'pre_expression', :'published' => :'published', :'range_attribute_id' => :'range_attribute_id', :'range_chance' => :'range_chance', :'tracking_speed_attribute_id' => :'tracking_speed_attribute_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 308 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 125 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 98 def self.openapi_types { :'description' => :'String', :'disallow_auto_repeat' => :'Boolean', :'discharge_attribute_id' => :'Integer', :'display_name' => :'String', :'duration_attribute_id' => :'Integer', :'effect_category' => :'Integer', :'effect_id' => :'Integer', :'electronic_chance' => :'Boolean', :'falloff_attribute_id' => :'Integer', :'icon_id' => :'Integer', :'is_assistance' => :'Boolean', :'is_offensive' => :'Boolean', :'is_warp_safe' => :'Boolean', :'modifiers' => :'Array<DogmaEffectsEffectIdGetModifiersInner>', :'name' => :'String', :'post_expression' => :'Integer', :'pre_expression' => :'Integer', :'published' => :'Boolean', :'range_attribute_id' => :'Integer', :'range_chance' => :'Boolean', :'tracking_speed_attribute_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 267 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && disallow_auto_repeat == o.disallow_auto_repeat && discharge_attribute_id == o.discharge_attribute_id && display_name == o.display_name && duration_attribute_id == o.duration_attribute_id && effect_category == o.effect_category && effect_id == o.effect_id && electronic_chance == o.electronic_chance && falloff_attribute_id == o.falloff_attribute_id && icon_id == o.icon_id && is_assistance == o.is_assistance && is_offensive == o.is_offensive && is_warp_safe == o.is_warp_safe && modifiers == o.modifiers && name == o.name && post_expression == o.post_expression && pre_expression == o.pre_expression && published == o.published && range_attribute_id == o.range_attribute_id && range_chance == o.range_chance && tracking_speed_attribute_id == o.tracking_speed_attribute_id end |
#eql?(o) ⇒ Boolean
295 296 297 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 295 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 301 def hash [description, disallow_auto_repeat, discharge_attribute_id, display_name, duration_attribute_id, effect_category, effect_id, electronic_chance, falloff_attribute_id, icon_id, is_assistance, is_offensive, is_warp_safe, modifiers, name, post_expression, pre_expression, published, range_attribute_id, range_chance, tracking_speed_attribute_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
237 238 239 240 241 242 243 244 245 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 237 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @effect_id.nil? invalid_properties.push('invalid value for "effect_id", effect_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 330 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
249 250 251 252 253 |
# File 'lib/ruby-esi/models/dogma_effects_effect_id_get.rb', line 249 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @effect_id.nil? true end |