Class: ESI::IncursionsGetInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::IncursionsGetInner
- Defined in:
- lib/ruby-esi/models/incursions_get_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#constellation_id ⇒ Object
The constellation id in which this incursion takes place.
-
#faction_id ⇒ Object
The attacking faction’s id.
-
#has_boss ⇒ Object
Whether the final encounter has boss or not.
-
#infested_solar_systems ⇒ Object
A list of infested solar system ids that are a part of this incursion.
-
#influence ⇒ Object
Influence of this incursion as a float from 0 to 1.
-
#staging_solar_system_id ⇒ Object
Staging solar system for this incursion.
-
#state ⇒ Object
The state of this incursion.
-
#type ⇒ Object
The type of this incursion.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IncursionsGetInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IncursionsGetInner
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::IncursionsGetInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::IncursionsGetInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'constellation_id') self.constellation_id = attributes[:'constellation_id'] else self.constellation_id = nil end if attributes.key?(:'faction_id') self.faction_id = attributes[:'faction_id'] else self.faction_id = nil end if attributes.key?(:'has_boss') self.has_boss = attributes[:'has_boss'] else self.has_boss = nil end if attributes.key?(:'infested_solar_systems') if (value = attributes[:'infested_solar_systems']).is_a?(Array) self.infested_solar_systems = value end else self.infested_solar_systems = nil end if attributes.key?(:'influence') self.influence = attributes[:'influence'] else self.influence = nil end if attributes.key?(:'staging_solar_system_id') self.staging_solar_system_id = attributes[:'staging_solar_system_id'] else self.staging_solar_system_id = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end end |
Instance Attribute Details
#constellation_id ⇒ Object
The constellation id in which this incursion takes place
19 20 21 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 19 def constellation_id @constellation_id end |
#faction_id ⇒ Object
The attacking faction’s id
22 23 24 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 22 def faction_id @faction_id end |
#has_boss ⇒ Object
Whether the final encounter has boss or not
25 26 27 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 25 def has_boss @has_boss end |
#infested_solar_systems ⇒ Object
A list of infested solar system ids that are a part of this incursion
28 29 30 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 28 def infested_solar_systems @infested_solar_systems end |
#influence ⇒ Object
Influence of this incursion as a float from 0 to 1
31 32 33 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 31 def influence @influence end |
#staging_solar_system_id ⇒ Object
Staging solar system for this incursion
34 35 36 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 34 def staging_solar_system_id @staging_solar_system_id end |
#state ⇒ Object
The state of this incursion
37 38 39 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 37 def state @state end |
#type ⇒ Object
The type of this incursion
40 41 42 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 40 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 65 def self.attribute_map { :'constellation_id' => :'constellation_id', :'faction_id' => :'faction_id', :'has_boss' => :'has_boss', :'infested_solar_systems' => :'infested_solar_systems', :'influence' => :'influence', :'staging_solar_system_id' => :'staging_solar_system_id', :'state' => :'state', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 342 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 89 def self.openapi_types { :'constellation_id' => :'Integer', :'faction_id' => :'Integer', :'has_boss' => :'Boolean', :'infested_solar_systems' => :'Array<Integer>', :'influence' => :'Float', :'staging_solar_system_id' => :'Integer', :'state' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 314 def ==(o) return true if self.equal?(o) self.class == o.class && constellation_id == o.constellation_id && faction_id == o.faction_id && has_boss == o.has_boss && infested_solar_systems == o.infested_solar_systems && influence == o.influence && staging_solar_system_id == o.staging_solar_system_id && state == o.state && type == o.type end |
#eql?(o) ⇒ Boolean
329 330 331 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 329 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 335 def hash [constellation_id, faction_id, has_boss, infested_solar_systems, influence, staging_solar_system_id, state, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @constellation_id.nil? invalid_properties.push('invalid value for "constellation_id", constellation_id cannot be nil.') end if @faction_id.nil? invalid_properties.push('invalid value for "faction_id", faction_id cannot be nil.') end if @has_boss.nil? invalid_properties.push('invalid value for "has_boss", has_boss cannot be nil.') end if @infested_solar_systems.nil? invalid_properties.push('invalid value for "infested_solar_systems", infested_solar_systems cannot be nil.') end if @influence.nil? invalid_properties.push('invalid value for "influence", influence cannot be nil.') end if @staging_solar_system_id.nil? invalid_properties.push('invalid value for "staging_solar_system_id", staging_solar_system_id cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/ruby-esi/models/incursions_get_inner.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @constellation_id.nil? return false if @faction_id.nil? return false if @has_boss.nil? return false if @infested_solar_systems.nil? return false if @influence.nil? return false if @staging_solar_system_id.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["withdrawing", "mobilizing", "established"]) return false unless state_validator.valid?(@state) return false if @type.nil? true end |