Class: ESI::KillmailsKillmailIdKillmailHashGetVictim
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- ESI::KillmailsKillmailIdKillmailHashGetVictim
- Defined in:
- lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb
Instance Attribute Summary collapse
-
#alliance_id ⇒ Object
Returns the value of attribute alliance_id.
-
#character_id ⇒ Object
Returns the value of attribute character_id.
-
#corporation_id ⇒ Object
Returns the value of attribute corporation_id.
-
#damage_taken ⇒ Object
How much total damage was taken by the victim.
-
#faction_id ⇒ Object
Returns the value of attribute faction_id.
-
#items ⇒ Object
Returns the value of attribute items.
-
#position ⇒ Object
Returns the value of attribute position.
-
#ship_type_id ⇒ Object
The ship that the victim was piloting and was destroyed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KillmailsKillmailIdKillmailHashGetVictim
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ KillmailsKillmailIdKillmailHashGetVictim
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `ESI::KillmailsKillmailIdKillmailHashGetVictim` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `ESI::KillmailsKillmailIdKillmailHashGetVictim`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'alliance_id') self.alliance_id = attributes[:'alliance_id'] end if attributes.key?(:'character_id') self.character_id = attributes[:'character_id'] end if attributes.key?(:'corporation_id') self.corporation_id = attributes[:'corporation_id'] end if attributes.key?(:'damage_taken') self.damage_taken = attributes[:'damage_taken'] else self.damage_taken = nil end if attributes.key?(:'faction_id') self.faction_id = attributes[:'faction_id'] end if attributes.key?(:'items') if (value = attributes[:'items']).is_a?(Array) self.items = value end end if attributes.key?(:'position') self.position = attributes[:'position'] end if attributes.key?(:'ship_type_id') self.ship_type_id = attributes[:'ship_type_id'] else self.ship_type_id = nil end end |
Instance Attribute Details
#alliance_id ⇒ Object
Returns the value of attribute alliance_id.
18 19 20 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 18 def alliance_id @alliance_id end |
#character_id ⇒ Object
Returns the value of attribute character_id.
20 21 22 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 20 def character_id @character_id end |
#corporation_id ⇒ Object
Returns the value of attribute corporation_id.
22 23 24 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 22 def corporation_id @corporation_id end |
#damage_taken ⇒ Object
How much total damage was taken by the victim
25 26 27 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 25 def damage_taken @damage_taken end |
#faction_id ⇒ Object
Returns the value of attribute faction_id.
27 28 29 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 27 def faction_id @faction_id end |
#items ⇒ Object
Returns the value of attribute items.
29 30 31 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 29 def items @items end |
#position ⇒ Object
Returns the value of attribute position.
31 32 33 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 31 def position @position end |
#ship_type_id ⇒ Object
The ship that the victim was piloting and was destroyed
34 35 36 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 34 def ship_type_id @ship_type_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 37 def self.attribute_map { :'alliance_id' => :'alliance_id', :'character_id' => :'character_id', :'corporation_id' => :'corporation_id', :'damage_taken' => :'damage_taken', :'faction_id' => :'faction_id', :'items' => :'items', :'position' => :'position', :'ship_type_id' => :'ship_type_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 61 def self.openapi_types { :'alliance_id' => :'Integer', :'character_id' => :'Integer', :'corporation_id' => :'Integer', :'damage_taken' => :'Integer', :'faction_id' => :'Integer', :'items' => :'Array<KillmailsKillmailIdKillmailHashGetVictimItemsInner>', :'position' => :'KillmailsKillmailIdKillmailHashGetVictimPosition', :'ship_type_id' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 182 def ==(o) return true if self.equal?(o) self.class == o.class && alliance_id == o.alliance_id && character_id == o.character_id && corporation_id == o.corporation_id && damage_taken == o.damage_taken && faction_id == o.faction_id && items == o.items && position == o.position && ship_type_id == o.ship_type_id end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 203 def hash [alliance_id, character_id, corporation_id, damage_taken, faction_id, items, position, ship_type_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @damage_taken.nil? invalid_properties.push('invalid value for "damage_taken", damage_taken cannot be nil.') end if @ship_type_id.nil? invalid_properties.push('invalid value for "ship_type_id", ship_type_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 |
# File 'lib/ruby-esi/models/killmails_killmail_id_killmail_hash_get_victim.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @damage_taken.nil? return false if @ship_type_id.nil? true end |