Class: ESI::MailApi
- Inherits:
-
Object
- Object
- ESI::MailApi
- Defined in:
- lib/ruby-esi/api/mail_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_characters_character_id_mail_labels_label_id(character_id, label_id, x_compatibility_date, opts = {}) ⇒ nil
Delete a mail label Delete a mail label.
-
#delete_characters_character_id_mail_labels_label_id_with_http_info(character_id, label_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a mail label Delete a mail label.
-
#delete_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ nil
Delete a mail Delete a mail.
-
#delete_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a mail Delete a mail.
-
#get_characters_character_id_mail(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdMailGetInner>
Return mail headers Return the 50 most recent mail headers belonging to the character that match the query criteria.
-
#get_characters_character_id_mail_labels(character_id, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdMailLabelsGet
Get mail labels and unread counts Return a list of the users mail labels, unread counts for each label and a total unread count.
-
#get_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdMailLabelsGet, Integer, Hash)>
Get mail labels and unread counts Return a list of the users mail labels, unread counts for each label and a total unread count.
-
#get_characters_character_id_mail_lists(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdMailListsGetInner>
Return mailing list subscriptions Return all mailing lists that the character is subscribed to.
-
#get_characters_character_id_mail_lists_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdMailListsGetInner>, Integer, Hash)>
Return mailing list subscriptions Return all mailing lists that the character is subscribed to.
-
#get_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdMailMailIdGet
Return a mail Return the contents of an EVE mail.
-
#get_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdMailMailIdGet, Integer, Hash)>
Return a mail Return the contents of an EVE mail.
-
#get_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdMailGetInner>, Integer, Hash)>
Return mail headers Return the 50 most recent mail headers belonging to the character that match the query criteria.
-
#initialize(api_client = ApiClient.default) ⇒ MailApi
constructor
A new instance of MailApi.
-
#post_characters_character_id_mail(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts = {}) ⇒ Integer
Send a new mail Create and send a new mail.
-
#post_characters_character_id_mail_labels(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts = {}) ⇒ Integer
Create a mail label Create a mail label.
-
#post_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts = {}) ⇒ Array<(Integer, Integer, Hash)>
Create a mail label Create a mail label.
-
#post_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts = {}) ⇒ Array<(Integer, Integer, Hash)>
Send a new mail Create and send a new mail.
-
#put_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts = {}) ⇒ nil
Update metadata about a mail Update metadata about a mail.
-
#put_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update metadata about a mail Update metadata about a mail.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ruby-esi/api/mail_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_characters_character_id_mail_labels_label_id(character_id, label_id, x_compatibility_date, opts = {}) ⇒ nil
Delete a mail label Delete a mail label
33 34 35 36 |
# File 'lib/ruby-esi/api/mail_api.rb', line 33 def delete_characters_character_id_mail_labels_label_id(character_id, label_id, x_compatibility_date, opts = {}) delete_characters_character_id_mail_labels_label_id_with_http_info(character_id, label_id, x_compatibility_date, opts) nil end |
#delete_characters_character_id_mail_labels_label_id_with_http_info(character_id, label_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a mail label Delete a mail label
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/ruby-esi/api/mail_api.rb', line 49 def delete_characters_character_id_mail_labels_label_id_with_http_info(character_id, label_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.delete_characters_character_id_mail_labels_label_id ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.delete_characters_character_id_mail_labels_label_id" end # verify the required parameter 'label_id' is set if @api_client.config.client_side_validation && label_id.nil? fail ArgumentError, "Missing the required parameter 'label_id' when calling MailApi.delete_characters_character_id_mail_labels_label_id" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.delete_characters_character_id_mail_labels_label_id" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/labels/{label_id}'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)).sub('{' + 'label_id' + '}', CGI.escape(label_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.delete_characters_character_id_mail_labels_label_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#delete_characters_character_id_mail_labels_label_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ nil
Delete a mail Delete a mail
130 131 132 133 |
# File 'lib/ruby-esi/api/mail_api.rb', line 130 def delete_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, opts = {}) delete_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts) nil end |
#delete_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a mail Delete a mail
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/ruby-esi/api/mail_api.rb', line 146 def delete_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.delete_characters_character_id_mail_mail_id ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.delete_characters_character_id_mail_mail_id" end # verify the required parameter 'mail_id' is set if @api_client.config.client_side_validation && mail_id.nil? fail ArgumentError, "Missing the required parameter 'mail_id' when calling MailApi.delete_characters_character_id_mail_mail_id" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.delete_characters_character_id_mail_mail_id" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/{mail_id}'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)).sub('{' + 'mail_id' + '}', CGI.escape(mail_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.delete_characters_character_id_mail_mail_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#delete_characters_character_id_mail_mail_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_characters_character_id_mail(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdMailGetInner>
Return mail headers Return the 50 most recent mail headers belonging to the character that match the query criteria. Queries can be filtered by label, and last_mail_id can be used to paginate backwards
228 229 230 231 |
# File 'lib/ruby-esi/api/mail_api.rb', line 228 def get_characters_character_id_mail(character_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, opts) data end |
#get_characters_character_id_mail_labels(character_id, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdMailLabelsGet
Get mail labels and unread counts Return a list of the users mail labels, unread counts for each label and a total unread count.
331 332 333 334 |
# File 'lib/ruby-esi/api/mail_api.rb', line 331 def get_characters_character_id_mail_labels(character_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, opts) data end |
#get_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdMailLabelsGet, Integer, Hash)>
Get mail labels and unread counts Return a list of the users mail labels, unread counts for each label and a total unread count.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/ruby-esi/api/mail_api.rb', line 346 def get_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.get_characters_character_id_mail_labels ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.get_characters_character_id_mail_labels" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.get_characters_character_id_mail_labels" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/labels'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CharactersCharacterIdMailLabelsGet' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.get_characters_character_id_mail_labels", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#get_characters_character_id_mail_labels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_characters_character_id_mail_lists(character_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdMailListsGetInner>
Return mailing list subscriptions Return all mailing lists that the character is subscribed to
422 423 424 425 |
# File 'lib/ruby-esi/api/mail_api.rb', line 422 def get_characters_character_id_mail_lists(character_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_mail_lists_with_http_info(character_id, x_compatibility_date, opts) data end |
#get_characters_character_id_mail_lists_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdMailListsGetInner>, Integer, Hash)>
Return mailing list subscriptions Return all mailing lists that the character is subscribed to
437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/ruby-esi/api/mail_api.rb', line 437 def get_characters_character_id_mail_lists_with_http_info(character_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.get_characters_character_id_mail_lists ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.get_characters_character_id_mail_lists" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.get_characters_character_id_mail_lists" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/lists'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdMailListsGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.get_characters_character_id_mail_lists", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#get_characters_character_id_mail_lists\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdMailMailIdGet
Return a mail Return the contents of an EVE mail
514 515 516 517 |
# File 'lib/ruby-esi/api/mail_api.rb', line 514 def get_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts) data end |
#get_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdMailMailIdGet, Integer, Hash)>
Return a mail Return the contents of an EVE mail
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/ruby-esi/api/mail_api.rb', line 530 def get_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.get_characters_character_id_mail_mail_id ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.get_characters_character_id_mail_mail_id" end # verify the required parameter 'mail_id' is set if @api_client.config.client_side_validation && mail_id.nil? fail ArgumentError, "Missing the required parameter 'mail_id' when calling MailApi.get_characters_character_id_mail_mail_id" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.get_characters_character_id_mail_mail_id" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/{mail_id}'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)).sub('{' + 'mail_id' + '}', CGI.escape(mail_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CharactersCharacterIdMailMailIdGet' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.get_characters_character_id_mail_mail_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#get_characters_character_id_mail_mail_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdMailGetInner>, Integer, Hash)>
Return mail headers Return the 50 most recent mail headers belonging to the character that match the query criteria. Queries can be filtered by label, and last_mail_id can be used to paginate backwards
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/ruby-esi/api/mail_api.rb', line 245 def get_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.get_characters_character_id_mail ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.get_characters_character_id_mail" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.get_characters_character_id_mail" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'labels'].nil? && opts[:'labels'].length > 25 fail ArgumentError, 'invalid value for "opts[:"labels"]" when calling MailApi.get_characters_character_id_mail, number of items must be less than or equal to 25.' end if @api_client.config.client_side_validation && !opts[:'labels'].nil? && opts[:'labels'].length < 1 fail ArgumentError, 'invalid value for "opts[:"labels"]" when calling MailApi.get_characters_character_id_mail, number of items must be greater than or equal to 1.' end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'labels'] = @api_client.build_collection_param(opts[:'labels'], :multi) if !opts[:'labels'].nil? query_params[:'last_mail_id'] = opts[:'last_mail_id'] if !opts[:'last_mail_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdMailGetInner>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.get_characters_character_id_mail", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#get_characters_character_id_mail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_characters_character_id_mail(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts = {}) ⇒ Integer
Send a new mail Create and send a new mail
611 612 613 614 |
# File 'lib/ruby-esi/api/mail_api.rb', line 611 def post_characters_character_id_mail(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts = {}) data, _status_code, _headers = post_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts) data end |
#post_characters_character_id_mail_labels(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts = {}) ⇒ Integer
Create a mail label Create a mail label
713 714 715 716 |
# File 'lib/ruby-esi/api/mail_api.rb', line 713 def post_characters_character_id_mail_labels(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts = {}) data, _status_code, _headers = post_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts) data end |
#post_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts = {}) ⇒ Array<(Integer, Integer, Hash)>
Create a mail label Create a mail label
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 |
# File 'lib/ruby-esi/api/mail_api.rb', line 729 def post_characters_character_id_mail_labels_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_labels_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.post_characters_character_id_mail_labels ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.post_characters_character_id_mail_labels" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.post_characters_character_id_mail_labels" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end # verify the required parameter 'post_characters_character_id_mail_labels_request' is set if @api_client.config.client_side_validation && post_characters_character_id_mail_labels_request.nil? fail ArgumentError, "Missing the required parameter 'post_characters_character_id_mail_labels_request' when calling MailApi.post_characters_character_id_mail_labels" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/labels'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(post_characters_character_id_mail_labels_request) # return_type return_type = opts[:debug_return_type] || 'Integer' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.post_characters_character_id_mail_labels", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#post_characters_character_id_mail_labels\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts = {}) ⇒ Array<(Integer, Integer, Hash)>
Send a new mail Create and send a new mail
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/ruby-esi/api/mail_api.rb', line 627 def post_characters_character_id_mail_with_http_info(character_id, x_compatibility_date, post_characters_character_id_mail_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.post_characters_character_id_mail ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.post_characters_character_id_mail" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.post_characters_character_id_mail" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end # verify the required parameter 'post_characters_character_id_mail_request' is set if @api_client.config.client_side_validation && post_characters_character_id_mail_request.nil? fail ArgumentError, "Missing the required parameter 'post_characters_character_id_mail_request' when calling MailApi.post_characters_character_id_mail" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(post_characters_character_id_mail_request) # return_type return_type = opts[:debug_return_type] || 'Integer' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.post_characters_character_id_mail", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#post_characters_character_id_mail\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts = {}) ⇒ nil
Update metadata about a mail Update metadata about a mail
816 817 818 819 |
# File 'lib/ruby-esi/api/mail_api.rb', line 816 def put_characters_character_id_mail_mail_id(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts = {}) put_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts) nil end |
#put_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update metadata about a mail Update metadata about a mail
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 |
# File 'lib/ruby-esi/api/mail_api.rb', line 833 def put_characters_character_id_mail_mail_id_with_http_info(character_id, mail_id, x_compatibility_date, put_characters_character_id_mail_mail_id_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MailApi.put_characters_character_id_mail_mail_id ...' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling MailApi.put_characters_character_id_mail_mail_id" end # verify the required parameter 'mail_id' is set if @api_client.config.client_side_validation && mail_id.nil? fail ArgumentError, "Missing the required parameter 'mail_id' when calling MailApi.put_characters_character_id_mail_mail_id" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling MailApi.put_characters_character_id_mail_mail_id" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end # verify the required parameter 'put_characters_character_id_mail_mail_id_request' is set if @api_client.config.client_side_validation && put_characters_character_id_mail_mail_id_request.nil? fail ArgumentError, "Missing the required parameter 'put_characters_character_id_mail_mail_id_request' when calling MailApi.put_characters_character_id_mail_mail_id" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/mail/{mail_id}'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)).sub('{' + 'mail_id' + '}', CGI.escape(mail_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(put_characters_character_id_mail_mail_id_request) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"MailApi.put_characters_character_id_mail_mail_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MailApi#put_characters_character_id_mail_mail_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |