Class: ESI::SearchApi
- Inherits:
-
Object
- Object
- ESI::SearchApi
- Defined in:
- lib/ruby-esi/api/search_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_characters_character_id_search(categories, character_id, search, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdSearchGet
Search on a string Search for entities that match a given sub-string.
-
#get_characters_character_id_search_with_http_info(categories, character_id, search, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdSearchGet, Integer, Hash)>
Search on a string Search for entities that match a given sub-string.
-
#initialize(api_client = ApiClient.default) ⇒ SearchApi
constructor
A new instance of SearchApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ruby-esi/api/search_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_characters_character_id_search(categories, character_id, search, x_compatibility_date, opts = {}) ⇒ CharactersCharacterIdSearchGet
Search on a string Search for entities that match a given sub-string.
35 36 37 38 |
# File 'lib/ruby-esi/api/search_api.rb', line 35 def get_characters_character_id_search(categories, character_id, search, x_compatibility_date, opts = {}) data, _status_code, _headers = get_characters_character_id_search_with_http_info(categories, character_id, search, x_compatibility_date, opts) data end |
#get_characters_character_id_search_with_http_info(categories, character_id, search, x_compatibility_date, opts = {}) ⇒ Array<(CharactersCharacterIdSearchGet, Integer, Hash)>
Search on a string Search for entities that match a given sub-string.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/ruby-esi/api/search_api.rb', line 53 def get_characters_character_id_search_with_http_info(categories, character_id, search, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SearchApi.get_characters_character_id_search ...' end # verify the required parameter 'categories' is set if @api_client.config.client_side_validation && categories.nil? fail ArgumentError, "Missing the required parameter 'categories' when calling SearchApi.get_characters_character_id_search" end if @api_client.config.client_side_validation && categories.length > 11 fail ArgumentError, 'invalid value for "categories" when calling SearchApi.get_characters_character_id_search, number of items must be less than or equal to 11.' end if @api_client.config.client_side_validation && categories.length < 1 fail ArgumentError, 'invalid value for "categories" when calling SearchApi.get_characters_character_id_search, number of items must be greater than or equal to 1.' end # verify the required parameter 'character_id' is set if @api_client.config.client_side_validation && character_id.nil? fail ArgumentError, "Missing the required parameter 'character_id' when calling SearchApi.get_characters_character_id_search" end # verify the required parameter 'search' is set if @api_client.config.client_side_validation && search.nil? fail ArgumentError, "Missing the required parameter 'search' when calling SearchApi.get_characters_character_id_search" end if @api_client.config.client_side_validation && search.to_s.length < 3 fail ArgumentError, 'invalid value for "search" when calling SearchApi.get_characters_character_id_search, the character length must be greater than or equal to 3.' end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling SearchApi.get_characters_character_id_search" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/characters/{character_id}/search'.sub('{' + 'character_id' + '}', CGI.escape(character_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'categories'] = @api_client.build_collection_param(categories, :multi) query_params[:'search'] = search query_params[:'strict'] = opts[:'strict'] if !opts[:'strict'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CharactersCharacterIdSearchGet' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"SearchApi.get_characters_character_id_search", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SearchApi#get_characters_character_id_search\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |