Class: ESI::WarsApi
- Inherits:
-
Object
- Object
- ESI::WarsApi
- Defined in:
- lib/ruby-esi/api/wars_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_wars(x_compatibility_date, opts = {}) ⇒ Array<Integer>
List wars Return a list of wars.
-
#get_wars_war_id(war_id, x_compatibility_date, opts = {}) ⇒ WarsWarIdGet
Get war information Return details about a war.
-
#get_wars_war_id_killmails(war_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdKillmailsRecentGetInner>
List kills for a war Return a list of kills related to a war.
-
#get_wars_war_id_killmails_with_http_info(war_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdKillmailsRecentGetInner>, Integer, Hash)>
List kills for a war Return a list of kills related to a war.
-
#get_wars_war_id_with_http_info(war_id, x_compatibility_date, opts = {}) ⇒ Array<(WarsWarIdGet, Integer, Hash)>
Get war information Return details about a war.
-
#get_wars_with_http_info(x_compatibility_date, opts = {}) ⇒ Array<(Array<Integer>, Integer, Hash)>
List wars Return a list of wars.
-
#initialize(api_client = ApiClient.default) ⇒ WarsApi
constructor
A new instance of WarsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/ruby-esi/api/wars_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_wars(x_compatibility_date, opts = {}) ⇒ Array<Integer>
List wars Return a list of wars
32 33 34 35 |
# File 'lib/ruby-esi/api/wars_api.rb', line 32 def get_wars(x_compatibility_date, opts = {}) data, _status_code, _headers = get_wars_with_http_info(x_compatibility_date, opts) data end |
#get_wars_war_id(war_id, x_compatibility_date, opts = {}) ⇒ WarsWarIdGet
Get war information Return details about a war
120 121 122 123 |
# File 'lib/ruby-esi/api/wars_api.rb', line 120 def get_wars_war_id(war_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_wars_war_id_with_http_info(war_id, x_compatibility_date, opts) data end |
#get_wars_war_id_killmails(war_id, x_compatibility_date, opts = {}) ⇒ Array<CharactersCharacterIdKillmailsRecentGetInner>
List kills for a war Return a list of kills related to a war
212 213 214 215 |
# File 'lib/ruby-esi/api/wars_api.rb', line 212 def get_wars_war_id_killmails(war_id, x_compatibility_date, opts = {}) data, _status_code, _headers = get_wars_war_id_killmails_with_http_info(war_id, x_compatibility_date, opts) data end |
#get_wars_war_id_killmails_with_http_info(war_id, x_compatibility_date, opts = {}) ⇒ Array<(Array<CharactersCharacterIdKillmailsRecentGetInner>, Integer, Hash)>
List kills for a war Return a list of kills related to a war
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/ruby-esi/api/wars_api.rb', line 228 def get_wars_war_id_killmails_with_http_info(war_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WarsApi.get_wars_war_id_killmails ...' end # verify the required parameter 'war_id' is set if @api_client.config.client_side_validation && war_id.nil? fail ArgumentError, "Missing the required parameter 'war_id' when calling WarsApi.get_wars_war_id_killmails" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WarsApi.get_wars_war_id_killmails" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1 fail ArgumentError, 'invalid value for "opts[:"page"]" when calling WarsApi.get_wars_war_id_killmails, must be greater than or equal to 1.' end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/wars/{war_id}/killmails'.sub('{' + 'war_id' + '}', CGI.escape(war_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<CharactersCharacterIdKillmailsRecentGetInner>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"WarsApi.get_wars_war_id_killmails", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WarsApi#get_wars_war_id_killmails\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_wars_war_id_with_http_info(war_id, x_compatibility_date, opts = {}) ⇒ Array<(WarsWarIdGet, Integer, Hash)>
Get war information Return details about a war
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/ruby-esi/api/wars_api.rb', line 135 def get_wars_war_id_with_http_info(war_id, x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WarsApi.get_wars_war_id ...' end # verify the required parameter 'war_id' is set if @api_client.config.client_side_validation && war_id.nil? fail ArgumentError, "Missing the required parameter 'war_id' when calling WarsApi.get_wars_war_id" end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WarsApi.get_wars_war_id" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/wars/{war_id}'.sub('{' + 'war_id' + '}', CGI.escape(war_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WarsWarIdGet' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"WarsApi.get_wars_war_id", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WarsApi#get_wars_war_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_wars_with_http_info(x_compatibility_date, opts = {}) ⇒ Array<(Array<Integer>, Integer, Hash)>
List wars Return a list of wars
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ruby-esi/api/wars_api.rb', line 47 def get_wars_with_http_info(x_compatibility_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WarsApi.get_wars ...' end # verify the required parameter 'x_compatibility_date' is set if @api_client.config.client_side_validation && x_compatibility_date.nil? fail ArgumentError, "Missing the required parameter 'x_compatibility_date' when calling WarsApi.get_wars" end # verify enum value allowable_values = ["2020-01-01"] if @api_client.config.client_side_validation && !allowable_values.include?(x_compatibility_date) fail ArgumentError, "invalid value for \"x_compatibility_date\", must be one of #{allowable_values}" end allowable_values = ["en", "de", "fr", "ja", "ru", "zh", "ko", "es"] if @api_client.config.client_side_validation && opts[:'accept_language'] && !allowable_values.include?(opts[:'accept_language']) fail ArgumentError, "invalid value for \"accept_language\", must be one of #{allowable_values}" end # resource path local_var_path = '/wars' # query parameters query_params = opts[:query_params] || {} query_params[:'max_war_id'] = opts[:'max_war_id'] if !opts[:'max_war_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Compatibility-Date'] = x_compatibility_date header_params[:'Accept-Language'] = opts[:'accept_language'] if !opts[:'accept_language'].nil? header_params[:'If-None-Match'] = opts[:'if_none_match'] if !opts[:'if_none_match'].nil? header_params[:'X-Tenant'] = opts[:'x_tenant'] if !opts[:'x_tenant'].nil? header_params[:'If-Modified-Since'] = opts[:'if_modified_since'] if !opts[:'if_modified_since'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Integer>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"WarsApi.get_wars", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WarsApi#get_wars\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |